
#############################################
#########   TRANS PROB SIM CODE    ##########
#############################################
rm(list=ls())
library(survival)
library(mstate)
library(foreign)

setwd("C:/Users/uspskm/Desktop/JCR replic")
source("alt_mssample.R")
dat <- read.dta("4 - h&a - continuous, disagg stages (5 stgs).dta")


dat$from <- dat$stage
dat$to <- dat$nextStage
dat$start <- dat$t0
dat$stop <- dat$t


#####################################
##### Prepare Transition Matrix #####
#####################################

tmat <- transMat(list(c(2, 3, 5), #transitions from challenge
			c(3, 4, 5), 		  #transitions from negotiate
			c(2, 4, 5), 	      #transitions from military
			c(2, 3, 5),			  #transition from inactive	
			c()),		
			names = c("challenge", "negotiate", "military", "inactive", "resolved"))

##### Convert Data Type
attr(dat, "trans") <- tmat
class(dat) <- c("msdata", "data.frame")

#Check number of transitions is correct
events(dat)
table(dat$status, dat$to, dat$from)


#Estimate Model
semi.4 <- coxph(Surv(start, stop, status) ~  
	milratio1 + strvalue1  + tgtodi1 + chgodi1 + netdemoc1 + onetdem1 +
	milratio2 + strvalue2  + tgtodi2 + chgodi2 + netdemoc2 + onetdem2 +
	milratio3 + strvalue3  + tgtodi3 + chgodi3 + netdemoc3 + onetdem3 +
	milratio4 + strvalue4  + tgtodi4 + chgodi4 + netdemoc4 + onetdem4 +
	milratio5 + strvalue5  + tgtodi5 + chgodi5 + netdemoc5 + onetdem5 +
	milratio6 + strvalue6  + tgtodi6 + chgodi6 + netdemoc6 + onetdem6 +
	milratio7 + strvalue7  + tgtodi7 + chgodi7 + netdemoc7 + onetdem7 +
	milratio8 + strvalue8  + tgtodi8 + chgodi8 + netdemoc8 + onetdem8 +
	milratio9 + strvalue9  + tgtodi9 + chgodi9 + netdemoc9 + onetdem9 +
	milratio10 + strvalue10  + tgtodi10 + chgodi10 + netdemoc10 + onetdem10 +
	milratio11 + strvalue11  + tgtodi11 + chgodi11 + netdemoc11 + onetdem11 +
	milratio12 + strvalue12  + tgtodi12 + chgodi12 + netdemoc12 + onetdem12 +

strata(trans), data = dat, method = "breslow", iter.max=500)
summary(semi.4)

#################################################
##### Plot Results of SemiParametric Models #####
#################################################

milratio1 <- as.vector(c(quantile(dat$milratio, .5, na.rm=TRUE),0,0,0,0,0,0,0,0,0,0,0))
milratio2 <- as.vector(c(0,quantile(dat$milratio, .5, na.rm=TRUE),0,0,0,0,0,0,0,0,0,0))
milratio3 <- as.vector(c(0,0,quantile(dat$milratio, .5, na.rm=TRUE),0,0,0,0,0,0,0,0,0))
milratio4 <- as.vector(c(0,0,0,quantile(dat$milratio, .5, na.rm=TRUE),0,0,0,0,0,0,0,0))
milratio5 <- as.vector(c(0,0,0,0,quantile(dat$milratio, .5, na.rm=TRUE),0,0,0,0,0,0,0))
milratio6 <- as.vector(c(0,0,0,0,0,quantile(dat$milratio, .5, na.rm=TRUE),0,0,0,0,0,0))
milratio7 <- as.vector(c(0,0,0,0,0,0,quantile(dat$milratio, .5, na.rm=TRUE),0,0,0,0,0))
milratio8 <- as.vector(c(0,0,0,0,0,0,0,quantile(dat$milratio, .5, na.rm=TRUE),0,0,0,0))
milratio9 <- as.vector(c(0,0,0,0,0,0,0,0,quantile(dat$milratio, .5, na.rm=TRUE),0,0,0))
milratio10 <- as.vector(c(0,0,0,0,0,0,0,0,0,quantile(dat$milratio, .5, na.rm=TRUE),0,0))
milratio11 <- as.vector(c(0,0,0,0,0,0,0,0,0,0,quantile(dat$milratio, .5, na.rm=TRUE),0))
milratio12 <- as.vector(c(0,0,0,0,0,0,0,0,0,0,0,quantile(dat$milratio, .5, na.rm=TRUE)))

strvalue1 <- as.vector(c(rep(0,12)))
strvalue1[1] <- quantile(dat$strvalue, .5, na.rm=TRUE)
strvalue2 <- as.vector(c(rep(0,12)))
strvalue2[2] <- quantile(dat$strvalue, .5, na.rm=TRUE)
strvalue3 <- as.vector(c(rep(0,12)))
strvalue3[3] <- quantile(dat$strvalue, .5, na.rm=TRUE)
strvalue4 <- as.vector(c(rep(0,12)))
strvalue4[4] <- quantile(dat$strvalue, .5, na.rm=TRUE)
strvalue5 <- as.vector(c(rep(0,12)))
strvalue5[5] <- quantile(dat$strvalue, .5, na.rm=TRUE)
strvalue6 <- as.vector(c(rep(0,12)))
strvalue6[6] <- quantile(dat$strvalue, .5, na.rm=TRUE)
strvalue7 <- as.vector(c(rep(0,12)))
strvalue7[7] <- quantile(dat$strvalue, .5, na.rm=TRUE)
strvalue8 <- as.vector(c(rep(0,12)))
strvalue8[8] <- quantile(dat$strvalue, .5, na.rm=TRUE)
strvalue9 <- as.vector(c(rep(0,12)))
strvalue9[9] <- quantile(dat$strvalue, .5, na.rm=TRUE)
strvalue10 <- as.vector(c(rep(0,12)))
strvalue10[10] <- quantile(dat$strvalue, .5, na.rm=TRUE)
strvalue11 <- as.vector(c(rep(0,12)))
strvalue11[11] <- quantile(dat$strvalue, .5, na.rm=TRUE)
strvalue12 <- as.vector(c(rep(0,12)))
strvalue12[12] <- quantile(dat$strvalue, .5, na.rm=TRUE)

tgtodi1 <- as.vector(c(rep(0,12)))
tgtodi1[1] <- quantile(dat$tgtodi, .5, na.rm=TRUE)
tgtodi2 <- as.vector(c(rep(0,12)))
tgtodi2[2] <- quantile(dat$tgtodi, .5, na.rm=TRUE)
tgtodi3 <- as.vector(c(rep(0,12)))
tgtodi3[3] <- quantile(dat$tgtodi, .5, na.rm=TRUE)
tgtodi4 <- as.vector(c(rep(0,12)))
tgtodi4[4] <- quantile(dat$tgtodi, .5, na.rm=TRUE)
tgtodi5 <- as.vector(c(rep(0,12)))
tgtodi5[5] <- quantile(dat$tgtodi, .5, na.rm=TRUE)
tgtodi6 <- as.vector(c(rep(0,12)))
tgtodi6[6] <- quantile(dat$tgtodi, .5, na.rm=TRUE)
tgtodi7 <- as.vector(c(rep(0,12)))
tgtodi7[7] <- quantile(dat$tgtodi, .5, na.rm=TRUE)
tgtodi8 <- as.vector(c(rep(0,12)))
tgtodi8[8] <- quantile(dat$tgtodi, .5, na.rm=TRUE)
tgtodi9 <- as.vector(c(rep(0,12)))
tgtodi9[9] <- quantile(dat$tgtodi, .5, na.rm=TRUE)
tgtodi10 <- as.vector(c(rep(0,12)))
tgtodi10[10] <- quantile(dat$tgtodi, .5, na.rm=TRUE)
tgtodi11 <- as.vector(c(rep(0,12)))
tgtodi11[11] <- quantile(dat$tgtodi, .5, na.rm=TRUE)
tgtodi12 <- as.vector(c(rep(0,12)))
tgtodi12[12] <- quantile(dat$tgtodi, .5, na.rm=TRUE)

chgodi1 <- as.vector(c(rep(0,12)))
chgodi1[1] <- quantile(dat$chgodi, .5, na.rm=TRUE)
chgodi2 <- as.vector(c(rep(0,12)))
chgodi2[2] <- quantile(dat$chgodi, .5, na.rm=TRUE)
chgodi3 <- as.vector(c(rep(0,12)))
chgodi3[3] <- quantile(dat$chgodi, .5, na.rm=TRUE)
chgodi4 <- as.vector(c(rep(0,12)))
chgodi4[4] <- quantile(dat$chgodi, .5, na.rm=TRUE)
chgodi5 <- as.vector(c(rep(0,12)))
chgodi5[5] <- quantile(dat$chgodi, .5, na.rm=TRUE)
chgodi6 <- as.vector(c(rep(0,12)))
chgodi6[6] <- quantile(dat$chgodi, .5, na.rm=TRUE)
chgodi7 <- as.vector(c(rep(0,12)))
chgodi7[7] <- quantile(dat$chgodi, .5, na.rm=TRUE)
chgodi8 <- as.vector(c(rep(0,12)))
chgodi8[8] <- quantile(dat$chgodi, .5, na.rm=TRUE)
chgodi9 <- as.vector(c(rep(0,12)))
chgodi9[9] <- quantile(dat$chgodi, .5, na.rm=TRUE)
chgodi10 <- as.vector(c(rep(0,12)))
chgodi10[10] <- quantile(dat$chgodi, .5, na.rm=TRUE)
chgodi11 <- as.vector(c(rep(0,12)))
chgodi11[11] <- quantile(dat$chgodi, .5, na.rm=TRUE)
chgodi12 <- as.vector(c(rep(0,12)))
chgodi12[12] <- quantile(dat$chgodi, .5, na.rm=TRUE)

onetdem1 <- as.vector(c(quantile(dat$onetdem, .5, na.rm=TRUE),0,0,0,0,0,0,0,0,0,0,0))
onetdem2 <- as.vector(c(0, quantile(dat$onetdem, .5, na.rm=TRUE),0,0,0,0,0,0,0,0,0,0))
onetdem3 <- as.vector(c(0,0, quantile(dat$onetdem, .5, na.rm=TRUE),0,0,0,0,0,0,0,0,0))
onetdem4 <- as.vector(c(0,0,0, quantile(dat$onetdem, .5, na.rm=TRUE),0,0,0,0,0,0,0,0))
onetdem5 <- as.vector(c(0,0,0,0, quantile(dat$onetdem, .5, na.rm=TRUE),0,0,0,0,0,0,0))
onetdem6 <- as.vector(c(0,0,0,0,0, quantile(dat$onetdem, .5, na.rm=TRUE) ,0,0,0,0,0,0))
onetdem7 <- as.vector(c(0,0,0,0,0,0, quantile(dat$onetdem, .5, na.rm=TRUE),0,0,0,0,0))
onetdem8 <- as.vector(c(0,0,0,0,0,0,0, quantile(dat$onetdem, .5, na.rm=TRUE),0,0,0,0))
onetdem9 <- as.vector(c(0,0,0,0,0,0,0,0, quantile(dat$onetdem, .5, na.rm=TRUE),0,0,0))
onetdem10 <- as.vector(c(0,0,0,0,0,0,0,0,0, quantile(dat$onetdem, .5, na.rm=TRUE),0,0))
onetdem11 <- as.vector(c(0,0,0,0,0,0,0,0,0,0, quantile(dat$onetdem, .5, na.rm=TRUE),0))
onetdem12 <- as.vector(c(0,0,0,0,0,0,0,0,0,0,0, quantile(dat$onetdem, .5, na.rm=TRUE)))

onetdem1 <- as.vector(c(quantile(dat$onetdem, .5, na.rm=TRUE),0,0,0,0,0,0,0,0,0,0,0))
onetdem2 <- as.vector(c(0,quantile(dat$onetdem, .5, na.rm=TRUE),0,0,0,0,0,0,0,0,0,0))
onetdem3 <- as.vector(c(0,0,quantile(dat$onetdem, .5, na.rm=TRUE),0,0,0,0,0,0,0,0,0))
onetdem4 <- as.vector(c(0,0,0,quantile(dat$onetdem, .5, na.rm=TRUE),0,0,0,0,0,0,0,0))
onetdem5 <- as.vector(c(0,0,0,0,quantile(dat$onetdem, .5, na.rm=TRUE),0,0,0,0,0,0,0))
onetdem6 <- as.vector(c(0,0,0,0,0,quantile(dat$onetdem, .5, na.rm=TRUE),0,0,0,0,0,0))
onetdem7 <- as.vector(c(0,0,0,0,0,0,quantile(dat$onetdem, .5, na.rm=TRUE),0,0,0,0,0))
onetdem8 <- as.vector(c(0,0,0,0,0,0,0,quantile(dat$onetdem, .5, na.rm=TRUE),0,0,0,0))
onetdem9 <- as.vector(c(0,0,0,0,0,0,0,0,quantile(dat$onetdem, .5, na.rm=TRUE),0,0,0))
onetdem10 <- as.vector(c(0,0,0,0,0,0,0,0,0,quantile(dat$onetdem, .5, na.rm=TRUE),0,0))
onetdem11 <- as.vector(c(0,0,0,0,0,0,0,0,0,0,quantile(dat$onetdem, .5, na.rm=TRUE),0))
onetdem12 <- as.vector(c(0,0,0,0,0,0,0,0,0,0,0,quantile(dat$onetdem, .5, na.rm=TRUE)))

#Set Challenger as Autocracy(25%, -8 net polity score)
netdemoc1 <- as.vector(rep(0,12))
netdemoc1[1]<- quantile(dat$netdemoc, .25)
netdemoc2 <- as.vector(rep(0,12))
netdemoc2[2]<- quantile(dat$netdemoc, .25)
netdemoc3 <- as.vector(rep(0,12))
netdemoc3[3]<- quantile(dat$netdemoc, .25)
netdemoc3 <- as.vector(rep(0,12))
netdemoc3[3]<- quantile(dat$netdemoc, .25)
netdemoc4 <- as.vector(rep(0,12))
netdemoc4[4]<- quantile(dat$netdemoc, .25)
netdemoc5 <- as.vector(rep(0,12))
netdemoc5[5]<- quantile(dat$netdemoc, .25)
netdemoc6 <- as.vector(rep(0,12))
netdemoc6[6]<- quantile(dat$netdemoc, .25)
netdemoc7 <- as.vector(rep(0,12))
netdemoc7[7]<- quantile(dat$netdemoc, .25)
netdemoc8 <- as.vector(rep(0,12))
netdemoc8[8]<- quantile(dat$netdemoc, .25)
netdemoc9 <- as.vector(rep(0,12))
netdemoc9[9]<- quantile(dat$netdemoc, .25)
netdemoc10 <- as.vector(rep(0,12))
netdemoc10[10]<- quantile(dat$netdemoc, .25)
netdemoc11 <- as.vector(rep(0,12))
netdemoc11[11]<- quantile(dat$netdemoc, .25)
netdemoc12 <- as.vector(rep(0,12))
netdemoc12[12]<- quantile(dat$netdemoc, .25)

#drop alliance variable for now
sit.aut <- data.frame(cbind(milratio1 , strvalue1  , tgtodi1 , chgodi1 , netdemoc1 , onetdem1 ,
	milratio2 , strvalue2  , tgtodi2 , chgodi2 , netdemoc2 , onetdem2 ,
	milratio3 , strvalue3  , tgtodi3 , chgodi3 , netdemoc3 , onetdem3 ,
	milratio4 , strvalue4  , tgtodi4 , chgodi4 , netdemoc4 , onetdem4 ,
	milratio5 , strvalue5  , tgtodi5 , chgodi5 , netdemoc5 , onetdem5 ,
	milratio6 , strvalue6  , tgtodi6 , chgodi6 , netdemoc6 , onetdem6 ,
	milratio7 , strvalue7  , tgtodi7 , chgodi7 , netdemoc7 , onetdem7 ,
	milratio8 , strvalue8  , tgtodi8 , chgodi8 , netdemoc8 , onetdem8 ,
	milratio9 , strvalue9  , tgtodi9 , chgodi9 , netdemoc9 , onetdem9 ,
	milratio10 , strvalue10  , tgtodi10 , chgodi10 , netdemoc10 , onetdem10 ,
	milratio11 , strvalue11  , tgtodi11 , chgodi11 , netdemoc11 , onetdem11 ,
	milratio12 , strvalue12  , tgtodi12 , chgodi12 , netdemoc12 , onetdem12 
	))

sit.aut$trans <- 1:12
attr(sit.aut, "trans") <- tmat
class(sit.aut) <- c("msdata", "data.frame")
sit.aut$strata<-sit.aut$trans

msf.aut <- msfit(semi.4, sit.aut, trans=tmat, variance=TRUE)



#Set Challenger as Democracy(75%, 7 net polity score)
netdemoc1 <- as.vector(rep(0,12))
netdemoc1[1]<- quantile(dat$netdemoc, .75)
netdemoc2 <- as.vector(rep(0,12))
netdemoc2[2]<- quantile(dat$netdemoc, .75)
netdemoc3 <- as.vector(rep(0,12))
netdemoc3[3]<- quantile(dat$netdemoc, .75)
netdemoc3 <- as.vector(rep(0,12))
netdemoc3[3]<- quantile(dat$netdemoc, .75)
netdemoc4 <- as.vector(rep(0,12))
netdemoc4[4]<- quantile(dat$netdemoc, .75)
netdemoc5 <- as.vector(rep(0,12))
netdemoc5[5]<- quantile(dat$netdemoc, .75)
netdemoc6 <- as.vector(rep(0,12))
netdemoc6[6]<- quantile(dat$netdemoc, .75)
netdemoc7 <- as.vector(rep(0,12))
netdemoc7[7]<- quantile(dat$netdemoc, .75)
netdemoc8 <- as.vector(rep(0,12))
netdemoc8[8]<- quantile(dat$netdemoc, .75)
netdemoc9 <- as.vector(rep(0,12))
netdemoc9[9]<- quantile(dat$netdemoc, .75)
netdemoc10 <- as.vector(rep(0,12))
netdemoc10[10]<- quantile(dat$netdemoc, .75)
netdemoc11 <- as.vector(rep(0,12))
netdemoc11[11]<- quantile(dat$netdemoc, .75)
netdemoc12 <- as.vector(rep(0,12))
netdemoc12[12]<- quantile(dat$netdemoc, .75)

#drop alliance variable for now
sit.dem <- data.frame(cbind(milratio1 , strvalue1  , tgtodi1 , chgodi1 , netdemoc1 , onetdem1 ,
	milratio2 , strvalue2  , tgtodi2 , chgodi2 , netdemoc2 , onetdem2 ,
	milratio3 , strvalue3  , tgtodi3 , chgodi3 , netdemoc3 , onetdem3 ,
	milratio4 , strvalue4  , tgtodi4 , chgodi4 , netdemoc4 , onetdem4 ,
	milratio5 , strvalue5  , tgtodi5 , chgodi5 , netdemoc5 , onetdem5 ,
	milratio6 , strvalue6  , tgtodi6 , chgodi6 , netdemoc6 , onetdem6 ,
	milratio7 , strvalue7  , tgtodi7 , chgodi7 , netdemoc7 , onetdem7 ,
	milratio8 , strvalue8  , tgtodi8 , chgodi8 , netdemoc8 , onetdem8 ,
	milratio9 , strvalue9  , tgtodi9 , chgodi9 , netdemoc9 , onetdem9 ,
	milratio10 , strvalue10  , tgtodi10 , chgodi10 , netdemoc10 , onetdem10 ,
	milratio11 , strvalue11  , tgtodi11 , chgodi11 , netdemoc11 , onetdem11 ,
	milratio12 , strvalue12  , tgtodi12 , chgodi12 , netdemoc12 , onetdem12 
	))


sit.dem$trans <- 1:12
attr(sit.dem, "trans") <- tmat
class(sit.dem) <- c("msdata", "data.frame")
sit.dem$strata<-sit.dem$trans
msf.dem <- msfit(semi.4, sit.dem, trans=tmat, variance=TRUE)
    
    
#Simulations for Autocratic Regimes Starting in Stage 2 @ 24mths
set.seed(1234)
tv <- seq(1,400)

# trying a loop
sims <- 1000
nIndvs <- 400

set.seed(280116)

    # first loop
    s <- 1
    temp <- mssamplea(Haz = msf.aut$Haz, trans = tmat, tvec=tv, history=list(state=2, time=12), M=nIndvs, clock="forward", output="state")
    transPrs <- cbind(s, temp)
    
    for(s in 2:sims) {
        print(s)
        temp <-mssamplea(Haz = msf.aut$Haz, trans = tmat, tvec=tv, history=list(state=2, time=12), M=nIndvs, clock="forward", output="state")
        temp <- cbind(s, temp) 
        transPrs <- rbind(transPrs, temp)
    }
    names(transPrs)[1] <- "simNo"
    
# WRITE FINAL PROCESSING HERE
final <- matrix(0, length(tv), dim(tmat)[1]*3 + 1)

for(t in 1:400)     {
    final[t,1] <- t 
    
    # stage 1
    final[t,2] <- mean(transPrs$pstate1[transPrs$time==t])
    final[t,3] <- quantile(transPrs$pstate1[transPrs$time==t], .025)
    final[t,4] <- quantile(transPrs$pstate1[transPrs$time==t], .975)
    
    # stage 2
    final[t,5] <- mean(transPrs$pstate2[transPrs$time==t])
    final[t,6] <- quantile(transPrs$pstate2[transPrs$time==t], .025)
    final[t,7] <- quantile(transPrs$pstate2[transPrs$time==t], .975)
    
    # stage 3
    final[t,8] <- mean(transPrs$pstate3[transPrs$time==t])
    final[t,9] <- quantile(transPrs$pstate3[transPrs$time==t], .025)
    final[t,10] <- quantile(transPrs$pstate3[transPrs$time==t], .975)
    
    # stage 4
    final[t,11] <- mean(transPrs$pstate4[transPrs$time==t])
    final[t,12] <- quantile(transPrs$pstate4[transPrs$time==t], .025)
    final[t,13] <- quantile(transPrs$pstate4[transPrs$time==t], .975)
    
    # stage 5
    final[t,14] <- mean(transPrs$pstate5[transPrs$time==t])
    final[t,15] <- quantile(transPrs$pstate5[transPrs$time==t], .025)
    final[t,16] <- quantile(transPrs$pstate5[transPrs$time==t], .975)
    
    
}
final.aut.neg <- data.frame(final)
    names(final.aut.neg) <- c("t",  "pstate1", "pstate1_l", "pstate1_u", "pstate2", "pstate2_l", "pstate2_u", 
                      "pstate3", "pstate3_l", "pstate3_u", "pstate4", "pstate4_l", "pstate4_u",
                      "pstate5", "pstate5_l", "pstate5_u")
  
save.image("Fig3_sims.RData")
    
## STARTING IN MILITARY
set.seed(260116)    
    # first loop
    s <- 1
    temp <- mssamplea(Haz = msf.aut$Haz, trans = tmat, tvec=tv, history=list(state=3, time=12), M=nIndvs, clock="forward", output="state")
    transPrs <- cbind(s, temp)
    
    for(s in 2:sims) {
        print(s)
        temp <-mssamplea(Haz = msf.aut$Haz, trans = tmat, tvec=tv, history=list(state=3, time=12), M=nIndvs, clock="forward", output="state")
        temp <- cbind(s, temp) 
        transPrs <- rbind(transPrs, temp)
    }
    names(transPrs)[1] <- "simNo"
    
    # WRITE FINAL PROCESSING HERE
    final <- matrix(0, length(tv), dim(tmat)[1]*3 + 1)
    
    for(t in 1:400)     {
        final[t,1] <- t 
        
        # stage 1
        final[t,2] <- mean(transPrs$pstate1[transPrs$time==t])
        final[t,3] <- quantile(transPrs$pstate1[transPrs$time==t], .025)
        final[t,4] <- quantile(transPrs$pstate1[transPrs$time==t], .975)
        
        # stage 2
        final[t,5] <- mean(transPrs$pstate2[transPrs$time==t])
        final[t,6] <- quantile(transPrs$pstate2[transPrs$time==t], .025)
        final[t,7] <- quantile(transPrs$pstate2[transPrs$time==t], .975)
        
        # stage 3
        final[t,8] <- mean(transPrs$pstate3[transPrs$time==t])
        final[t,9] <- quantile(transPrs$pstate3[transPrs$time==t], .025)
        final[t,10] <- quantile(transPrs$pstate3[transPrs$time==t], .975)
        
        # stage 4
        final[t,11] <- mean(transPrs$pstate4[transPrs$time==t])
        final[t,12] <- quantile(transPrs$pstate4[transPrs$time==t], .025)
        final[t,13] <- quantile(transPrs$pstate4[transPrs$time==t], .975)
        
        # stage 5
        final[t,14] <- mean(transPrs$pstate5[transPrs$time==t])
        final[t,15] <- quantile(transPrs$pstate5[transPrs$time==t], .025)
        final[t,16] <- quantile(transPrs$pstate5[transPrs$time==t], .975)
        
        
    }
    final.aut.mil <- data.frame(final)
    names(final.aut.mil) <- c("t",  "pstate1", "pstate1_l", "pstate1_u", "pstate2", "pstate2_l", "pstate2_u", 
                              "pstate3", "pstate3_l", "pstate3_u", "pstate4", "pstate4_l", "pstate4_u",
                              "pstate5", "pstate5_l", "pstate5_u")
    
    save.image("Fig3_sims.RData")   
#*******************************************************************************
# Do same for democ
    
set.seed(131075)
    
    # first loop
    s <- 1
    temp <- mssamplea(Haz = msf.dem$Haz, trans = tmat, tvec=tv, history=list(state=2, time=12), M=nIndvs, clock="forward", output="state")
    transPrs <- cbind(s, temp)
    
    for(s in 2:sims) {
        print(s)
        temp <-mssamplea(Haz = msf.dem$Haz, trans = tmat, tvec=tv, history=list(state=2, time=12), M=nIndvs, clock="forward", output="state")
        temp <- cbind(s, temp) 
        transPrs <- rbind(transPrs, temp)
    }
    names(transPrs)[1] <- "simNo"
    
    # WRITE FINAL PROCESSING HERE
    final <- matrix(0, length(tv), dim(tmat)[1]*3 + 1)
    
    for(t in 1:400)     {
        final[t,1] <- t 
        
        # stage 1
        final[t,2] <- mean(transPrs$pstate1[transPrs$time==t])
        final[t,3] <- quantile(transPrs$pstate1[transPrs$time==t], .025)
        final[t,4] <- quantile(transPrs$pstate1[transPrs$time==t], .975)
        
        # stage 2
        final[t,5] <- mean(transPrs$pstate2[transPrs$time==t])
        final[t,6] <- quantile(transPrs$pstate2[transPrs$time==t], .025)
        final[t,7] <- quantile(transPrs$pstate2[transPrs$time==t], .975)
        
        # stage 3
        final[t,8] <- mean(transPrs$pstate3[transPrs$time==t])
        final[t,9] <- quantile(transPrs$pstate3[transPrs$time==t], .025)
        final[t,10] <- quantile(transPrs$pstate3[transPrs$time==t], .975)
        
        # stage 4
        final[t,11] <- mean(transPrs$pstate4[transPrs$time==t])
        final[t,12] <- quantile(transPrs$pstate4[transPrs$time==t], .025)
        final[t,13] <- quantile(transPrs$pstate4[transPrs$time==t], .975)
        
        # stage 5
        final[t,14] <- mean(transPrs$pstate5[transPrs$time==t])
        final[t,15] <- quantile(transPrs$pstate5[transPrs$time==t], .025)
        final[t,16] <- quantile(transPrs$pstate5[transPrs$time==t], .975)
        
        
    }
    final.dem.neg <- data.frame(final)
    names(final.dem.neg) <- c("t",  "pstate1", "pstate1_l", "pstate1_u", "pstate2", "pstate2_l", "pstate2_u", 
                              "pstate3", "pstate3_l", "pstate3_u", "pstate4", "pstate4_l", "pstate4_u",
                              "pstate5", "pstate5_l", "pstate5_u")
    
save.image("Fig3_sims.RData")
    
## STARTING IN MILITARY
set.seed(101175)

# first loop
s <- 1
temp <- mssamplea(Haz = msf.dem$Haz, trans = tmat, tvec=tv, history=list(state=3, time=12), M=nIndvs, clock="forward", output="state")
transPrs <- cbind(s, temp)

for(s in 2:sims) {
    print(s)
    temp <-mssamplea(Haz = msf.dem$Haz, trans = tmat, tvec=tv, history=list(state=3, time=12), M=nIndvs, clock="forward", output="state")
    temp <- cbind(s, temp) 
    transPrs <- rbind(transPrs, temp)
}
names(transPrs)[1] <- "simNo"

# WRITE FINAL PROCESSING HERE
final <- matrix(0, length(tv), dim(tmat)[1]*3 + 1)

for(t in 1:400)     {
    final[t,1] <- t 
    
    # stage 1
    final[t,2] <- mean(transPrs$pstate1[transPrs$time==t])
    final[t,3] <- quantile(transPrs$pstate1[transPrs$time==t], .025)
    final[t,4] <- quantile(transPrs$pstate1[transPrs$time==t], .975)
    
    # stage 2
    final[t,5] <- mean(transPrs$pstate2[transPrs$time==t])
    final[t,6] <- quantile(transPrs$pstate2[transPrs$time==t], .025)
    final[t,7] <- quantile(transPrs$pstate2[transPrs$time==t], .975)
    
    # stage 3
    final[t,8] <- mean(transPrs$pstate3[transPrs$time==t])
    final[t,9] <- quantile(transPrs$pstate3[transPrs$time==t], .025)
    final[t,10] <- quantile(transPrs$pstate3[transPrs$time==t], .975)
    
    # stage 4
    final[t,11] <- mean(transPrs$pstate4[transPrs$time==t])
    final[t,12] <- quantile(transPrs$pstate4[transPrs$time==t], .025)
    final[t,13] <- quantile(transPrs$pstate4[transPrs$time==t], .975)
    
    # stage 5
    final[t,14] <- mean(transPrs$pstate5[transPrs$time==t])
    final[t,15] <- quantile(transPrs$pstate5[transPrs$time==t], .025)
    final[t,16] <- quantile(transPrs$pstate5[transPrs$time==t], .975)
    
    
}
final.dem.mil <- data.frame(final)
names(final.dem.mil) <- c("t",  "pstate1", "pstate1_l", "pstate1_u", "pstate2", "pstate2_l", "pstate2_u", 
                          "pstate3", "pstate3_l", "pstate3_u", "pstate4", "pstate4_l", "pstate4_u",
                          "pstate5", "pstate5_l", "pstate5_u")

save.image("Fig3_sims.RData")
