
########################################################################################
######### Replicate the results of Table 4, a Multi-State Model with 4 Stages ##########
########################################################################################

rm(list=ls())
library(foreign)
library(survival)
library(mstate)

dat <- read.dta("2 - h&a - continuous, no TVC.dta")

dat$from <- dat$stage + 1
dat$to <- dat$nextStage + 1
dat$start <- dat$t0
dat$stop <- dat$t

#####################################
##### Prepare Transition Matrix #####
#####################################

tmat <- transMat(list(c(2, 3, 4), #transitions from challenge
			c(1, 3, 4), 		  #transitions from negotiate
			c(1, 2, 4), 	      #transitions from military
			c()),				  #transition from resolved			
			names = c("challenge", "negotiate", "military", "resolved"))

##### Convert Data Type To Mstate Format #####
attr(dat, "trans") <- tmat
class(dat) <- c("msdata", "data.frame")


############################################
###### Estimate Semi-Parametric Model ######
############################################

###Rename Variables for Consistency with Transition Numbering

dat$milratio1 <- dat$milratioA
dat$milratio2 <- dat$milratioB
dat$milratio3 <- dat$milratioG
dat$milratio4 <- dat$milratioC
dat$milratio5 <- dat$milratioD
dat$milratio6 <- dat$milratioH
dat$milratio7 <- dat$milratioF
dat$milratio8 <- dat$milratioE
dat$milratio9 <- dat$milratioI

dat$strvalue1 <- dat$strvalueA
dat$strvalue2 <- dat$strvalueB
dat$strvalue3 <- dat$strvalueG
dat$strvalue4 <- dat$strvalueC
dat$strvalue5 <- dat$strvalueD
dat$strvalue6 <- dat$strvalueH
dat$strvalue7 <- dat$strvalueF
dat$strvalue8 <- dat$strvalueE
dat$strvalue9 <- dat$strvalueI

dat$allianceHA1 <- dat$allianceHAA
dat$allianceHA2 <- dat$allianceHAB
dat$allianceHA3 <- dat$allianceHAG
dat$allianceHA4 <- dat$allianceHAC
dat$allianceHA5 <- dat$allianceHAD
dat$allianceHA6 <- dat$allianceHAH
dat$allianceHA7 <- dat$allianceHAF
dat$allianceHA8 <- dat$allianceHAE
dat$allianceHA9 <- dat$allianceHAI

dat$tgtodi1 <- dat$tgtodiA
dat$tgtodi2 <- dat$tgtodiB
dat$tgtodi3 <- dat$tgtodiG
dat$tgtodi4 <- dat$tgtodiC
dat$tgtodi5 <- dat$tgtodiD
dat$tgtodi6 <- dat$tgtodiH
dat$tgtodi7 <- dat$tgtodiF
dat$tgtodi8 <- dat$tgtodiE
dat$tgtodi9 <- dat$tgtodiI

dat$chgodi1 <- dat$chgodiA
dat$chgodi2 <- dat$chgodiB
dat$chgodi3 <- dat$chgodiG
dat$chgodi4 <- dat$chgodiC
dat$chgodi5 <- dat$chgodiD
dat$chgodi6 <- dat$chgodiH
dat$chgodi7 <- dat$chgodiF
dat$chgodi8 <- dat$chgodiE
dat$chgodi9 <- dat$chgodiI

dat$netdemoc1 <- dat$netdemocA
dat$netdemoc2 <- dat$netdemocB
dat$netdemoc3 <- dat$netdemocG
dat$netdemoc4 <- dat$netdemocC
dat$netdemoc5 <- dat$netdemocD
dat$netdemoc6 <- dat$netdemocH
dat$netdemoc7 <- dat$netdemocF
dat$netdemoc8 <- dat$netdemocE
dat$netdemoc9 <- dat$netdemocI

dat$onetdem1 <- dat$onetdemA
dat$onetdem2 <- dat$onetdemB
dat$onetdem3 <- dat$onetdemG
dat$onetdem4 <- dat$onetdemC
dat$onetdem5 <- dat$onetdemD
dat$onetdem6 <- dat$onetdemH
dat$onetdem7 <- dat$onetdemF
dat$onetdem8 <- dat$onetdemE
dat$onetdem9 <- dat$onetdemI

#Estimate a multi-state model with transition-specific covariates and baseline hazards stratified by transition
semi.4 <- coxph(Surv(start, stop, status) ~  
	milratio1 + strvalue1  + tgtodi1 + chgodi1 + netdemoc1 + onetdem1 +
	milratio2 + strvalue2  + tgtodi2 + chgodi2 + netdemoc2 + onetdem2 +
	milratio3 + strvalue3  + tgtodi3 + chgodi3 + netdemoc3 + onetdem3 +
	milratio4 + strvalue4  + tgtodi4 + chgodi4 + netdemoc4 + onetdem4 +
	milratio5 + strvalue5  + tgtodi5 + chgodi5 + netdemoc5 + onetdem5 +
	milratio6 + strvalue6  + tgtodi6 + chgodi6 + netdemoc6 + onetdem6 +
	milratio7 + strvalue7  + tgtodi7 + chgodi7 + netdemoc7 + onetdem7 +
	milratio8 + strvalue8  + tgtodi8 + chgodi8 + netdemoc8 + onetdem8 +
	milratio9 + strvalue9  + tgtodi9 + chgodi9 + netdemoc9 + onetdem9 +
strata(trans), data = dat, method = "efron")
summary(semi.4)

