
###############################################################################################
######### Replicate the results of Table 12, Generate Predictions from 5 Stage Model ##########
###############################################################################################

rm(list=ls())
library(foreign)
library(survival)
library(mstate)

dat <- read.dta("4 - h&a - continuous, disagg stages (5 stgs).dta")

dat$from <- dat$stage
dat$to <- dat$nextStage
dat$start <- dat$t0
dat$stop <- dat$t

#####################################
##### Prepare Transition Matrix #####
#####################################

tmat <- transMat(list(c(2, 3, 5), #transitions from challenge
			c(3, 4, 5), 		  #transitions from negotiate
			c(2, 4, 5), 	      #transitions from military
			c(2, 3, 5),			  #transition from inactive	
			c()),		
			names = c("challenge", "negotiate", "military", "inactive", "resolved"))

##### Convert Data Type To Mstate Format #####
attr(dat, "trans") <- tmat
class(dat) <- c("msdata", "data.frame")


############################################
###### Estimate Semi-Parametric Model ######
############################################

semi.4 <- coxph(Surv(start, stop, status) ~  
	milratio1 + strvalue1  + tgtodi1 + chgodi1 + netdemoc1 + onetdem1 +
	milratio2 + strvalue2  + tgtodi2 + chgodi2 + netdemoc2 + onetdem2 +
	milratio3 + strvalue3  + tgtodi3 + chgodi3 + netdemoc3 + onetdem3 +
	milratio4 + strvalue4  + tgtodi4 + chgodi4 + netdemoc4 + onetdem4 +
	milratio5 + strvalue5  + tgtodi5 + chgodi5 + netdemoc5 + onetdem5 +
	milratio6 + strvalue6  + tgtodi6 + chgodi6 + netdemoc6 + onetdem6 +
	milratio7 + strvalue7  + tgtodi7 + chgodi7 + netdemoc7 + onetdem7 +
	milratio8 + strvalue8  + tgtodi8 + chgodi8 + netdemoc8 + onetdem8 +
	milratio9 + strvalue9  + tgtodi9 + chgodi9 + netdemoc9 + onetdem9 +
	milratio10 + strvalue10  + tgtodi10 + chgodi10 + netdemoc10 + onetdem10 +
	milratio11 + strvalue11  + tgtodi11 + chgodi11 + netdemoc11 + onetdem11 +
	milratio12 + strvalue12  + tgtodi12 + chgodi12 + netdemoc12 + onetdem12 +

strata(trans), data = dat, method = "efron")
summary(semi.4)


#####################################################
############# Generate Predicted Values #############
#####################################################

#Restrict dataset to first observation for each dispute dyad
dat.sm <- subset(dat, dat$firstTrans == 1)

#Generate empty storage object to hold predictions
pred <- list()

for(i in 1:nrow(dat.sm)){
	
	#Assign Prediction Values Based on ith Dispute
	mil <- dat.sm$milratio1[i]
	str <- dat.sm$strvalue1[i]
	tgt <- dat.sm$tgtodi1[i]
	chg <- dat.sm$chgodi1[i]
	net <- dat.sm$netdemoc1[i]
	one <- dat.sm$onetdem1[i]
	
	#Generate Transition Specific Version of Data
	milratio1 <- as.vector(rep(0,12))
	milratio1[1]<- mil
	milratio2 <- as.vector(rep(0,12))
	milratio2[2]<- mil
	milratio3 <- as.vector(rep(0,12))
	milratio3[3]<- mil
	milratio4 <- as.vector(rep(0,12))
	milratio4[4]<- mil
	milratio5 <- as.vector(rep(0,12))
	milratio5[5]<- mil
	milratio6 <- as.vector(rep(0,12))
	milratio6[6]<- mil
	milratio7 <- as.vector(rep(0,12))
	milratio7[7]<- mil
	milratio8 <- as.vector(rep(0,12))
	milratio8[8]<- mil
	milratio9 <- as.vector(rep(0,12))
	milratio9[9]<- mil
	milratio10 <- as.vector(rep(0,12))
	milratio10[10]<- mil
	milratio11 <- as.vector(rep(0,12))
	milratio11[11]<- mil
	milratio12 <- as.vector(rep(0,12))
	milratio12[12]<- mil
	
	strvalue1 <- as.vector(rep(0,12))
	strvalue1[1]<- str
	strvalue2 <- as.vector(rep(0,12))
	strvalue2[2]<- str
	strvalue3 <- as.vector(rep(0,12))
	strvalue3[3]<- str
	strvalue4 <- as.vector(rep(0,12))
	strvalue4[4]<- str
	strvalue5 <- as.vector(rep(0,12))
	strvalue5[5]<- str
	strvalue6 <- as.vector(rep(0,12))
	strvalue6[6]<- str
	strvalue7 <- as.vector(rep(0,12))
	strvalue7[7]<- str
	strvalue8 <- as.vector(rep(0,12))
	strvalue8[8]<- str
	strvalue9 <- as.vector(rep(0,12))
	strvalue9[9]<- str
	strvalue10 <- as.vector(rep(0,12))
	strvalue10[10]<- str
	strvalue11 <- as.vector(rep(0,12))
	strvalue11[11]<- str
	strvalue12 <- as.vector(rep(0,12))
	strvalue12[12]<- str
	
	tgtodi1 <- as.vector(rep(0,12))
	tgtodi1[1]<- tgt
	tgtodi2 <- as.vector(rep(0,12))
	tgtodi2[2]<- tgt
	tgtodi3 <- as.vector(rep(0,12))
	tgtodi3[3]<- tgt
	tgtodi4 <- as.vector(rep(0,12))
	tgtodi4[4]<- tgt
	tgtodi5 <- as.vector(rep(0,12))
	tgtodi5[5]<- tgt
	tgtodi6 <- as.vector(rep(0,12))
	tgtodi6[6]<- tgt
	tgtodi7 <- as.vector(rep(0,12))
	tgtodi7[7]<- tgt
	tgtodi8 <- as.vector(rep(0,12))
	tgtodi8[8]<- tgt
	tgtodi9 <- as.vector(rep(0,12))
	tgtodi9[9]<- tgt
	tgtodi10 <- as.vector(rep(0,12))
	tgtodi10[10]<- tgt
	tgtodi11 <- as.vector(rep(0,12))
	tgtodi11[11]<- tgt
	tgtodi12 <- as.vector(rep(0,12))
	tgtodi12[12]<- tgt
	
	chgodi1 <- as.vector(rep(0,12))
	chgodi1[1]<- chg
	chgodi2 <- as.vector(rep(0,12))
	chgodi2[2]<- chg
	chgodi3 <- as.vector(rep(0,12))
	chgodi3[3]<- chg
	chgodi4 <- as.vector(rep(0,12))
	chgodi4[4]<- chg
	chgodi5 <- as.vector(rep(0,12))
	chgodi5[5]<- chg
	chgodi6 <- as.vector(rep(0,12))
	chgodi6[6]<- chg
	chgodi7 <- as.vector(rep(0,12))
	chgodi7[7]<- chg
	chgodi8 <- as.vector(rep(0,12))
	chgodi8[8]<- chg
	chgodi9 <- as.vector(rep(0,12))
	chgodi9[9]<- chg
	chgodi10 <- as.vector(rep(0,12))
	chgodi10[10]<- chg
	chgodi11 <- as.vector(rep(0,12))
	chgodi11[11]<- chg
	chgodi12 <- as.vector(rep(0,12))
	chgodi12[12]<- chg
	
	netdemoc1 <- as.vector(rep(0,12))
	netdemoc1[1]<- net
	netdemoc2 <- as.vector(rep(0,12))
	netdemoc2[2]<- net
	netdemoc3 <- as.vector(rep(0,12))
	netdemoc3[3]<- net
	netdemoc4 <- as.vector(rep(0,12))
	netdemoc4[4]<- net
	netdemoc5 <- as.vector(rep(0,12))
	netdemoc5[5]<- net
	netdemoc6 <- as.vector(rep(0,12))
	netdemoc6[6]<- net
	netdemoc7 <- as.vector(rep(0,12))
	netdemoc7[7]<- net
	netdemoc8 <- as.vector(rep(0,12))
	netdemoc8[8]<- net
	netdemoc9 <- as.vector(rep(0,12))
	netdemoc9[9]<- net
	netdemoc10 <- as.vector(rep(0,12))
	netdemoc10[10]<- net
	netdemoc11 <- as.vector(rep(0,12))
	netdemoc11[11]<- net
	netdemoc12 <- as.vector(rep(0,12))
	netdemoc12[12]<- net
	
	onetdem1 <- as.vector(rep(0,12))
	onetdem1[1]<- one
	onetdem2 <- as.vector(rep(0,12))
	onetdem2[2]<- one
	onetdem3 <- as.vector(rep(0,12))
	onetdem3[3]<- one
	onetdem4 <- as.vector(rep(0,12))
	onetdem4[4]<- one
	onetdem5 <- as.vector(rep(0,12))
	onetdem5[5]<- one
	onetdem6 <- as.vector(rep(0,12))
	onetdem6[6]<- one
	onetdem7 <- as.vector(rep(0,12))
	onetdem7[7]<- one
	onetdem8 <- as.vector(rep(0,12))
	onetdem8[8]<- one
	onetdem9 <- as.vector(rep(0,12))
	onetdem9[9]<- one
	onetdem10 <- as.vector(rep(0,12))
	onetdem10[10]<- one
	onetdem11 <- as.vector(rep(0,12))
	onetdem11[11]<- one
	onetdem12 <- as.vector(rep(0,12))
	onetdem12[12]<- one

	#Combine transition-specific covariates into a single dataframe
	sit.tmp <- data.frame(cbind(milratio1 , strvalue1  , tgtodi1 , chgodi1 , netdemoc1 , onetdem1 ,
	milratio2 , strvalue2  , tgtodi2 , chgodi2 , netdemoc2 , onetdem2 ,
	milratio3 , strvalue3  , tgtodi3 , chgodi3 , netdemoc3 , onetdem3 ,
	milratio4 , strvalue4  , tgtodi4 , chgodi4 , netdemoc4 , onetdem4 ,
	milratio5 , strvalue5  , tgtodi5 , chgodi5 , netdemoc5 , onetdem5 ,
	milratio6 , strvalue6  , tgtodi6 , chgodi6 , netdemoc6 , onetdem6 ,
	milratio7 , strvalue7  , tgtodi7 , chgodi7 , netdemoc7 , onetdem7 ,
	milratio8 , strvalue8  , tgtodi8 , chgodi8 , netdemoc8 , onetdem8 ,
	milratio9 , strvalue9  , tgtodi9 , chgodi9 , netdemoc9 , onetdem9 ,
	milratio10 , strvalue10  , tgtodi10 , chgodi10 , netdemoc10 , onetdem10 ,
	milratio11 , strvalue11  , tgtodi11 , chgodi11 , netdemoc11 , onetdem11 ,
	milratio12 , strvalue12  , tgtodi12 , chgodi12 , netdemoc12 , onetdem12 
	))

	#Add transition numbers, and Mstate formatting
	sit.tmp$trans <- 1:12
	attr(sit.tmp, "trans") <- tmat
	class(sit.tmp) <- c("msdata", "data.frame")
	sit.tmp$strata <- sit.tmp$trans

	#Estimate cumulative hazards
	msf.tmp <- msfit(semi.4, sit.tmp, trans=tmat, variance=FALSE)
	
	#Estimate transition probabilities
	pt.tmp <- probtrans(msf.tmp, predt = 0, variance=FALSE)

	#Store transition probabilities
	pred[[i]]<- cbind(pt.tmp[[1]], dat.sm$claimDySwID[i])
	
	print(i)
}

#####Determine Predicted Probabilities#####
detach(dat.sm)

predict <- cbind(as.vector(rep(NA, 401)), as.vector(rep(NA, 401)))

#For each dispute dyad at t=24, identify the stage with the highest probability of being occupied to generate a prediction of which stage a dispute dyad is most likely to occupy.
for(i in 1:401){
	tmp <- pred[[i]]
	predict[i,1] <- apply(tmp[25,2:6], 1, which.max)
	predict[i,2] <- tmp[25,7]
	}

#Store predictions
predict <- as.data.frame(predict)
colnames(predict) <- c("pred", "claimDySwID")

write.dta(predict, "Mstate_Predictions.dta",version=12)
	