
#####################################################
######### Replicate the results of Table 5 ##########
#####################################################

rm(list=ls())
library(foreign)
library(survival)
library(mstate)

dat <- read.dta("4 - h&a - continuous, disagg stages (5 stgs).dta")

dat$from <- dat$stage
dat$to <- dat$nextStage
dat$start <- dat$t0
dat$stop <- dat$t

#####################################
##### Prepare Transition Matrix #####
#####################################

tmat <- transMat(list(c(2, 3, 5), #transitions from challenge
			c(3, 4, 5), 		  #transitions from negotiate
			c(2, 4, 5), 	      #transitions from military
			c(2, 3, 5),			  #transition from inactive	
			c()),		
			names = c("challenge", "negotiate", "military", "inactive", "resolved"))

##### Convert Data Type To Mstate Format #####
attr(dat, "trans") <- tmat
class(dat) <- c("msdata", "data.frame")


############################################
###### Estimate Semi-Parametric Model ######
############################################

semi.4 <- coxph(Surv(start, stop, status) ~  
	milratio1 + strvalue1  + tgtodi1 + chgodi1 + netdemoc1 + onetdem1 +
	milratio2 + strvalue2  + tgtodi2 + chgodi2 + netdemoc2 + onetdem2 +
	milratio3 + strvalue3  + tgtodi3 + chgodi3 + netdemoc3 + onetdem3 +
	milratio4 + strvalue4  + tgtodi4 + chgodi4 + netdemoc4 + onetdem4 +
	milratio5 + strvalue5  + tgtodi5 + chgodi5 + netdemoc5 + onetdem5 +
	milratio6 + strvalue6  + tgtodi6 + chgodi6 + netdemoc6 + onetdem6 +
	milratio7 + strvalue7  + tgtodi7 + chgodi7 + netdemoc7 + onetdem7 +
	milratio8 + strvalue8  + tgtodi8 + chgodi8 + netdemoc8 + onetdem8 +
	milratio9 + strvalue9  + tgtodi9 + chgodi9 + netdemoc9 + onetdem9 +
	milratio10 + strvalue10  + tgtodi10 + chgodi10 + netdemoc10 + onetdem10 +
	milratio11 + strvalue11  + tgtodi11 + chgodi11 + netdemoc11 + onetdem11 +
	milratio12 + strvalue12  + tgtodi12 + chgodi12 + netdemoc12 + onetdem12 +

strata(trans), data = dat, method = "efron")
summary(semi.4)

	

###################################################################
###### Estimate Transition Probabilities Depicted in Table 5 ######
###################################################################

###### Set all transition-specific covariates at median values #####
strvalue1 <- as.vector(c(rep(0,12)))
strvalue2 <- as.vector(c(rep(0,12)))
strvalue3 <- as.vector(c(rep(0,12)))
strvalue4 <- as.vector(c(rep(0,12)))
strvalue5 <- as.vector(c(rep(0,12)))
strvalue6 <- as.vector(c(rep(0,12)))
strvalue7 <- as.vector(c(rep(0,12)))
strvalue8 <- as.vector(c(rep(0,12)))
strvalue9 <- as.vector(c(rep(0,12)))
strvalue10 <- as.vector(c(rep(0,12)))
strvalue11 <- as.vector(c(rep(0,12)))
strvalue12 <- as.vector(c(rep(0,12)))
strvalue1[1] <- 1
strvalue2[2] <- 1
strvalue3[3] <- 1
strvalue4[4] <- 1
strvalue5[5] <- 1
strvalue6[6] <- 1
strvalue7[7] <- 1
strvalue8[8] <- 1
strvalue9[9] <- 1
strvalue10[10] <- 1
strvalue11[11] <- 1
strvalue12[12] <- 1

tgtodi1 <- as.vector(c(rep(0,12)))
tgtodi2 <- as.vector(c(rep(0,12)))
tgtodi3 <- as.vector(c(rep(0,12)))
tgtodi4 <- as.vector(c(rep(0,12)))
tgtodi5 <- as.vector(c(rep(0,12)))
tgtodi6 <- as.vector(c(rep(0,12)))
tgtodi7 <- as.vector(c(rep(0,12)))
tgtodi8 <- as.vector(c(rep(0,12)))
tgtodi9 <- as.vector(c(rep(0,12)))
tgtodi10 <- as.vector(c(rep(0,12)))
tgtodi11 <- as.vector(c(rep(0,12)))
tgtodi12 <- as.vector(c(rep(0,12)))

chgodi1 <- as.vector(c(rep(0,12)))
chgodi2 <- as.vector(c(rep(0,12)))
chgodi3 <- as.vector(c(rep(0,12)))
chgodi4 <- as.vector(c(rep(0,12)))
chgodi5 <- as.vector(c(rep(0,12)))
chgodi6 <- as.vector(c(rep(0,12)))
chgodi7 <- as.vector(c(rep(0,12)))
chgodi8 <- as.vector(c(rep(0,12)))
chgodi9 <- as.vector(c(rep(0,12)))
chgodi10 <- as.vector(c(rep(0,12)))
chgodi11 <- as.vector(c(rep(0,12)))
chgodi12 <- as.vector(c(rep(0,12)))

milratio1 <- as.vector(c(.4,0,0,0,0,0,0,0,0,0,0,0))
milratio2 <- as.vector(c(0,.4,0,0,0,0,0,0,0,0,0,0))
milratio3 <- as.vector(c(0,0,.4,0,0,0,0,0,0,0,0,0))
milratio4 <- as.vector(c(0,0,0,.4,0,0,0,0,0,0,0,0))
milratio5 <- as.vector(c(0,0,0,0,.4,0,0,0,0,0,0,0))
milratio6 <- as.vector(c(0,0,0,0,0,.4,0,0,0,0,0,0))
milratio7 <- as.vector(c(0,0,0,0,0,0,.4,0,0,0,0,0))
milratio8 <- as.vector(c(0,0,0,0,0,0,0,.4,0,0,0,0))
milratio9 <- as.vector(c(0,0,0,0,0,0,0,0,.4,0,0,0))
milratio10 <- as.vector(c(0,0,0,0,0,0,0,0,0,.4,0,0))
milratio11 <- as.vector(c(0,0,0,0,0,0,0,0,0,0,.4,0))
milratio12 <- as.vector(c(0,0,0,0,0,0,0,0,0,0,0,.4))

onetdem1 <- as.vector(rep(0,12))
onetdem1[1]<- -2
onetdem2 <- as.vector(rep(0,12))
onetdem2[2]<- -2
onetdem3 <- as.vector(rep(0,12))
onetdem3[3]<- -2
onetdem3 <- as.vector(rep(0,12))
onetdem3[3]<- -2
onetdem4 <- as.vector(rep(0,12))
onetdem4[4]<- -2
onetdem5 <- as.vector(rep(0,12))
onetdem5[5]<- -2
onetdem6 <- as.vector(rep(0,12))
onetdem6[6]<- -2
onetdem7 <- as.vector(rep(0,12))
onetdem7[7]<- -2
onetdem8 <- as.vector(rep(0,12))
onetdem8[8]<- -2
onetdem9 <- as.vector(rep(0,12))
onetdem9[9]<- -2
onetdem10 <- as.vector(rep(0,12))
onetdem10[10]<- -2
onetdem11 <- as.vector(rep(0,12))
onetdem11[11]<- -2
onetdem12 <- as.vector(rep(0,12))
onetdem12[12]<- -2


###### Vary the value of challenger democracy #####

#Set Challenger Democracy to -10
netdemoc1 <- as.vector(rep(0,12))
netdemoc1[1]<- -10
netdemoc2 <- as.vector(rep(0,12))
netdemoc2[2]<- -10
netdemoc3 <- as.vector(rep(0,12))
netdemoc3[3]<- -10
netdemoc3 <- as.vector(rep(0,12))
netdemoc3[3]<- -10
netdemoc4 <- as.vector(rep(0,12))
netdemoc4[4]<- -10
netdemoc5 <- as.vector(rep(0,12))
netdemoc5[5]<- -10
netdemoc6 <- as.vector(rep(0,12))
netdemoc6[6]<- -10
netdemoc7 <- as.vector(rep(0,12))
netdemoc7[7]<- -10
netdemoc8 <- as.vector(rep(0,12))
netdemoc8[8]<- -10
netdemoc9 <- as.vector(rep(0,12))
netdemoc9[9]<- -10
netdemoc10 <- as.vector(rep(0,12))
netdemoc10[10]<- -10
netdemoc11 <- as.vector(rep(0,12))
netdemoc11[11]<- -10
netdemoc12 <- as.vector(rep(0,12))
netdemoc12[12]<- -10

#Combine transition-specific covariates into a single dataframe
sit.p.neg10 <- data.frame(cbind(milratio1 , strvalue1  , tgtodi1 , chgodi1 , netdemoc1 , onetdem1 ,
	milratio2 , strvalue2  , tgtodi2 , chgodi2 , netdemoc2 , onetdem2 ,
	milratio3 , strvalue3  , tgtodi3 , chgodi3 , netdemoc3 , onetdem3 ,
	milratio4 , strvalue4  , tgtodi4 , chgodi4 , netdemoc4 , onetdem4 ,
	milratio5 , strvalue5  , tgtodi5 , chgodi5 , netdemoc5 , onetdem5 ,
	milratio6 , strvalue6  , tgtodi6 , chgodi6 , netdemoc6 , onetdem6 ,
	milratio7 , strvalue7  , tgtodi7 , chgodi7 , netdemoc7 , onetdem7 ,
	milratio8 , strvalue8  , tgtodi8 , chgodi8 , netdemoc8 , onetdem8 ,
	milratio9 , strvalue9  , tgtodi9 , chgodi9 , netdemoc9 , onetdem9 ,
	milratio10 , strvalue10  , tgtodi10 , chgodi10 , netdemoc10 , onetdem10 ,
	milratio11 , strvalue11  , tgtodi11 , chgodi11 , netdemoc11 , onetdem11 ,
	milratio12 , strvalue12  , tgtodi12 , chgodi12 , netdemoc12 , onetdem12 
	))

#Add transition numbers, and Mstate formatting
sit.p.neg10$trans <- 1:12
attr(sit.p.neg10, "trans") <- tmat
class(sit.p.neg10) <- c("msdata", "data.frame")
sit.p.neg10$strata<-sit.p.neg10$trans

#Estimate cumulative hazards
msf.p.neg10 <- msfit(semi.4, sit.p.neg10, trans=tmat, variance=TRUE)

#Estimate transition probabilities with challenger democracy at -10
pt.p.neg10 <- probtrans(msf.p.neg10, predt = 24, variance=FALSE)

#Transition probabilities at t=25, with challenger democracy at -10
pt.p.neg10[[4]][2,]


#Set Challenger Democracy to -2
netdemoc1 <- as.vector(rep(0,12))
netdemoc1[1]<- -2
netdemoc2 <- as.vector(rep(0,12))
netdemoc2[2]<- -2
netdemoc3 <- as.vector(rep(0,12))
netdemoc3[3]<- -2
netdemoc3 <- as.vector(rep(0,12))
netdemoc3[3]<- -2
netdemoc4 <- as.vector(rep(0,12))
netdemoc4[4]<- -2
netdemoc5 <- as.vector(rep(0,12))
netdemoc5[5]<- -2
netdemoc6 <- as.vector(rep(0,12))
netdemoc6[6]<- -2
netdemoc7 <- as.vector(rep(0,12))
netdemoc7[7]<- -2
netdemoc8 <- as.vector(rep(0,12))
netdemoc8[8]<- -2
netdemoc9 <- as.vector(rep(0,12))
netdemoc9[9]<- -2
netdemoc10 <- as.vector(rep(0,12))
netdemoc10[10]<- -2
netdemoc11 <- as.vector(rep(0,12))
netdemoc11[11]<- -2
netdemoc12 <- as.vector(rep(0,12))
netdemoc12[12]<- -2

#Combine transition-specific covariates into a single dataframe
sit.p.neg2 <- data.frame(cbind(milratio1 , strvalue1  , tgtodi1 , chgodi1 , netdemoc1 , onetdem1 ,
	milratio2 , strvalue2  , tgtodi2 , chgodi2 , netdemoc2 , onetdem2 ,
	milratio3 , strvalue3  , tgtodi3 , chgodi3 , netdemoc3 , onetdem3 ,
	milratio4 , strvalue4  , tgtodi4 , chgodi4 , netdemoc4 , onetdem4 ,
	milratio5 , strvalue5  , tgtodi5 , chgodi5 , netdemoc5 , onetdem5 ,
	milratio6 , strvalue6  , tgtodi6 , chgodi6 , netdemoc6 , onetdem6 ,
	milratio7 , strvalue7  , tgtodi7 , chgodi7 , netdemoc7 , onetdem7 ,
	milratio8 , strvalue8  , tgtodi8 , chgodi8 , netdemoc8 , onetdem8 ,
	milratio9 , strvalue9  , tgtodi9 , chgodi9 , netdemoc9 , onetdem9 ,
	milratio10 , strvalue10  , tgtodi10 , chgodi10 , netdemoc10 , onetdem10 ,
	milratio11 , strvalue11  , tgtodi11 , chgodi11 , netdemoc11 , onetdem11 ,
	milratio12 , strvalue12  , tgtodi12 , chgodi12 , netdemoc12 , onetdem12 
	))

#Add transition numbers, and Mstate formatting
sit.p.neg2$trans <- 1:12
attr(sit.p.neg2, "trans") <- tmat
class(sit.p.neg2) <- c("msdata", "data.frame")
sit.p.neg2$strata<-sit.p.neg2$trans

#Estimate cumulative hazards
msf.p.neg2 <- msfit(semi.4, sit.p.neg2, trans=tmat, variance=TRUE)

#Estimate transition probabilities with challenger democracy at -2
pt.p.neg2 <- probtrans(msf.p.neg2, predt = 24, variance=TRUE)

#Transition probabilities at t=25, with challenger democracy at -2
pt.p.neg2[[4]][2,]


#Set Challenger Democracy to 6
netdemoc1 <- as.vector(rep(0,12))
netdemoc1[1]<- 6
netdemoc2 <- as.vector(rep(0,12))
netdemoc2[2]<- 6
netdemoc3 <- as.vector(rep(0,12))
netdemoc3[3]<- 6
netdemoc3 <- as.vector(rep(0,12))
netdemoc3[3]<- 6
netdemoc4 <- as.vector(rep(0,12))
netdemoc4[4]<- 6
netdemoc5 <- as.vector(rep(0,12))
netdemoc5[5]<- 6
netdemoc6 <- as.vector(rep(0,12))
netdemoc6[6]<- 6
netdemoc7 <- as.vector(rep(0,12))
netdemoc7[7]<- 6
netdemoc8 <- as.vector(rep(0,12))
netdemoc8[8]<- 6
netdemoc9 <- as.vector(rep(0,12))
netdemoc9[9]<- 6
netdemoc10 <- as.vector(rep(0,12))
netdemoc10[10]<- 6
netdemoc11 <- as.vector(rep(0,12))
netdemoc11[11]<- 6
netdemoc12 <- as.vector(rep(0,12))
netdemoc12[12]<- 6

#Combine transition-specific covariates into a single dataframe
sit.p.6 <- data.frame(cbind(milratio1 , strvalue1  , tgtodi1 , chgodi1 , netdemoc1 , onetdem1 ,
	milratio2 , strvalue2  , tgtodi2 , chgodi2 , netdemoc2 , onetdem2 ,
	milratio3 , strvalue3  , tgtodi3 , chgodi3 , netdemoc3 , onetdem3 ,
	milratio4 , strvalue4  , tgtodi4 , chgodi4 , netdemoc4 , onetdem4 ,
	milratio5 , strvalue5  , tgtodi5 , chgodi5 , netdemoc5 , onetdem5 ,
	milratio6 , strvalue6  , tgtodi6 , chgodi6 , netdemoc6 , onetdem6 ,
	milratio7 , strvalue7  , tgtodi7 , chgodi7 , netdemoc7 , onetdem7 ,
	milratio8 , strvalue8  , tgtodi8 , chgodi8 , netdemoc8 , onetdem8 ,
	milratio9 , strvalue9  , tgtodi9 , chgodi9 , netdemoc9 , onetdem9 ,
	milratio10 , strvalue10  , tgtodi10 , chgodi10 , netdemoc10 , onetdem10 ,
	milratio11 , strvalue11  , tgtodi11 , chgodi11 , netdemoc11 , onetdem11 ,
	milratio12 , strvalue12  , tgtodi12 , chgodi12 , netdemoc12 , onetdem12 
	))

#Add transition numbers, and Mstate formatting
sit.p.6$trans <- 1:12
attr(sit.p.6, "trans") <- tmat
class(sit.p.6) <- c("msdata", "data.frame")
sit.p.6$strata<-sit.p.6$trans

#Estimate cumulative hazards
msf.p.6 <- msfit(semi.4, sit.p.6, trans=tmat, variance=TRUE)

#Estimate transition probabilities with challenger democracy at 6
pt.p.6 <- probtrans(msf.p.6, predt = 24, variance=TRUE)

#Transition probabilities at t=25, with challenger democracy at 6
pt.p.6[[4]][2,]



#Set Challenger Democracy to 10
netdemoc1 <- as.vector(rep(0,12))
netdemoc1[1]<- 10
netdemoc2 <- as.vector(rep(0,12))
netdemoc2[2]<- 10
netdemoc3 <- as.vector(rep(0,12))
netdemoc3[3]<- 10
netdemoc3 <- as.vector(rep(0,12))
netdemoc3[3]<- 10
netdemoc4 <- as.vector(rep(0,12))
netdemoc4[4]<- 10
netdemoc5 <- as.vector(rep(0,12))
netdemoc5[5]<- 10
netdemoc10 <- as.vector(rep(0,12))
netdemoc10[6]<- 10
netdemoc7 <- as.vector(rep(0,12))
netdemoc7[7]<- 10
netdemoc8 <- as.vector(rep(0,12))
netdemoc8[8]<- 10
netdemoc9 <- as.vector(rep(0,12))
netdemoc9[9]<- 10
netdemoc10 <- as.vector(rep(0,12))
netdemoc10[10]<- 10
netdemoc11 <- as.vector(rep(0,12))
netdemoc11[11]<- 10
netdemoc12 <- as.vector(rep(0,12))
netdemoc12[12]<- 10

#Combine transition-specific covariates into a single dataframe
sit.p.10 <- data.frame(cbind(milratio1 , strvalue1  , tgtodi1 , chgodi1 , netdemoc1 , onetdem1 ,
	milratio2 , strvalue2  , tgtodi2 , chgodi2 , netdemoc2 , onetdem2 ,
	milratio3 , strvalue3  , tgtodi3 , chgodi3 , netdemoc3 , onetdem3 ,
	milratio4 , strvalue4  , tgtodi4 , chgodi4 , netdemoc4 , onetdem4 ,
	milratio5 , strvalue5  , tgtodi5 , chgodi5 , netdemoc5 , onetdem5 ,
	milratio6 , strvalue6  , tgtodi6 , chgodi6 , netdemoc6 , onetdem6 ,
	milratio7 , strvalue7  , tgtodi7 , chgodi7 , netdemoc7 , onetdem7 ,
	milratio8 , strvalue8  , tgtodi8 , chgodi8 , netdemoc8 , onetdem8 ,
	milratio9 , strvalue9  , tgtodi9 , chgodi9 , netdemoc9 , onetdem9 ,
	milratio10 , strvalue10  , tgtodi10 , chgodi10 , netdemoc10 , onetdem10 ,
	milratio11 , strvalue11  , tgtodi11 , chgodi11 , netdemoc11 , onetdem11 ,
	milratio12 , strvalue12  , tgtodi12 , chgodi12 , netdemoc12 , onetdem12 
	))

#Add transition numbers, and Mstate formatting
sit.p.10$trans <- 1:12
attr(sit.p.10, "trans") <- tmat
class(sit.p.10) <- c("msdata", "data.frame")
sit.p.10$strata<-sit.p.10$trans

#Estimate cumulative hazards
msf.p.10 <- msfit(semi.4, sit.p.10, trans=tmat, variance=TRUE)

#Estimate transition probabilities with challenger democracy at 10
pt.p.10 <- probtrans(msf.p.10, predt = 24, variance=TRUE)

#Transition probabilities at t=25, with challenger democracy at 10
pt.p.10[[4]][2,]
