use "4 - huth_allee_statusquodata, v0 (orig).dta" , clear

// right censoring variable (needed to get proper end obsv for censored)
qui do "_all - ongoing disputes.do"


// gen unique claim-dyad identifier
id dispno2 chall targ, gen(claimDy)
xtset claimDy datetm

clonevar lengthBackup = length

	
// preserve the dataset for the merge on all vars
tempfile clDy

preserve
	keep claimDy dispno dispno2 region challenger target chgname tgtname datetm
	duplicates drop claimDy, force
	sort claimDy datetm
	drop datetm
	save `clDy', replace
restore

gen orig = 1
order orig claimDy, first
gen origCount = sum(orig)

gen stage = dvsq1 
order stage, before(dvsq1)


// [13JUL14] - just get rid of stupid dispno2==292 error--nuke the IRN-UKG dyad in the middle (will actually make mstate stuff more correct)
drop if(dispno2==292 & datetm==tm(1938m1))


// The colonial fix [11JUL14]
{ // start of colonial fix
* gen start, end dates
gen startDate = datetm - (msafinal - 1)
format startDate %tm
order startDate, after(datetm)
	//for anything that appears to start before 1919m1, replace the date with 1919m1
	replace startDate = tm(1919m1) if(startDate<tm(1919m1))
	
gen endDate = datetm + (length-1)	// Because it's inclusive.  Ooooops.
format endDate %tm
order endDate, after(datetm)

	
// [13JUL14]  HANDFIXES
	* the stupid coding error for dispno2==75.  Book says it starts in 1919m1, but dataset says otherwise.  Force the update.
	replace startDate = tm(1919m1) if(dispno2==75)
	
	* for dispno2==75.  Book says it ends in 1945 (assuming VJ Day, given what this dispute's over, so m8), but dataset says otherwise.  Force the update. 
	replace endDate = tm(1945m8) if(dispno2==126)


* merge in the independence dates for the ccodes
preserve
	tempfile states
	import delimited "states2011 [ccode].csv", clear
	rename statenme name
	duplicates tag ccode, gen(temp)
	drop if(styear<1919 & temp==1)
		// Which countries have multiples remaining after 1919?
		/*	- Luxembourg, ccode==212. (1920, 1944) 
			- Austria, ccode==305. (1919, 1955) 
        	- Syria, ccode==652. (1946, 1961)
			
			Are these countries involved with any of the disputes that we have to reconcile?  (would affect which obsv. to keep) 
			
			- Luxembourg: NO.
				edit if(numClDy>1 & sampleFlag==1 & (challenger==212 | target==212))
			- Austria: NO
				edit if(numClDy>1 & sampleFlag==1 & (challenger==305 | target==305))
        	- Syria: NO.
				edit if(numClDy>1 & sampleFlag==1 & (challenger==652 | target==652))
			
			So--doesn't matter.  Just drop what duplicates are left.
			*/
	
	drop temp	
	duplicates drop ccode, force
	
	clonevar challenger = ccode
	clonevar target  = ccode
	
	* indp dates (for the cases that have multiples, they aren't the colonies
	gen indpDate1 = ym(styear, stmonth)
	format indpDate1 %tm
	
	gen indpDate2 = ym(styear, stmonth)
	format indpDate2 %tm
	
	save `states', replace
restore

merge challenger using `states', uniqusing sort nokeep keep(indpDate1)
tab _m
drop _m

merge target using `states', uniqusing sort nokeep keep(indpDate2)
tab _m
drop _m

// Which country changes--chal or tgt?
* temp counter
bysort dispno2 (datetm claimDy ): gen tempCounter = _n

xtset dispno2 tempCounter

bysort dispno2 (claimDy datetm): gen diff = (claimDy[_n] !=claimDy[_n-1])
bysort dispno2 (datetm claimDy ): gen runSum = sum(diff)
bysort dispno2 (claimDy datetm): egenD numClDy = total(diff), label(Total number of dyads in dispute)

order diff runSum, first
sort dispno2 datetm

genD change1 = ., label(1 if chal changes in first switch, 2 if tgt changes, . if no 1st sw)
genD change2 = ., label(1 if chal changes in second switch, 2 if tgt changes, . if no 2nd sw)
genD colonialEnd = 0, label(1 if clDy ends because of colonial switch, 0 oth.)

recode change1 (.=0) if(numClDy > 1 & runSum==1) //recode the change variables to 0, for sanity purposes, for any multiple clDy
recode change2 (.=0) if(numClDy > 2 & runSum <3) 

	* first switch
	sort dispno2 tempCounter
	recode change1 (.=1) if(diff==1 & challenger!=L1.challenger & target==L1.target & runSum==2)
	recode change1 (.=2) if(diff==1 & challenger==L1.challenger & target!=L1.target & runSum==2)

	bysort claimDy (datetm): egen temp = max(change1)
	replace change1 = temp if (runSum==2 & change1==.)
	drop temp

	* second switch
	sort dispno2 tempCounter
	recode change2 (.=1) if(diff==1 & challenger!=L1.challenger & target==L1.target & runSum==3)
	recode change2 (.=2) if(diff==1 & challenger==L1.challenger & target!=L1.target & runSum==3)

	bysort claimDy (datetm): egen temp = max(change2)
	replace change2 = temp if (runSum==3 & change2==.)
	drop temp
	

// Deal with 2-dyad cases first	(and the first switch for the non-weird 3-dyad cases)
	// For the start date of dyad 2, needs to be equivalent to independence date
	gen tempStDate = indpDate1 if(numClDy>1 & (dispno2!=11 & dispno2!=12) & change1==1 & runSum==2)
	replace tempStDate = indpDate2 if(numClDy>1 & (dispno2!=11 & dispno2!=12) & change1==2 & runSum==2)
	format tempStDate %tm
	
	replace startDate = tempStDate if(numClDy>1 & (dispno2!=11 & dispno2!=12) & runSum==2)

	
	// For end date of dyad 1, needs to be the month RIGHT BEFORE independence for 2
	sort dispno2 tempCounter
	gen t1 = F1.indpDate1 if(F1.diff==1 & (dispno2!=11 & dispno2!=12) & numClDy>1)
	gen t2 = F1.indpDate2 if(F1.diff==1 & (dispno2!=11 & dispno2!=12) & numClDy>1)
	format t1 t2 %tm
	
	gen tempEndDate = (t1 - 1) if(numClDy>1 & F1.change1==1 & (dispno2!=11 & dispno2!=12) )
	replace tempEndDate = (t2 - 1) if(numClDy>1 & F1.change1==2 & (dispno2!=11 & dispno2!=12))
	format tempEndDate %tm	
	
	replace endDate = tempEndDate if(numClDy>1 & (dispno2!=11 & dispno2!=12) & runSum==1)
		// don't think I have to max this by claimDy, because of how the end obsvs fill in a little while.
	
	recode colonialEnd (0=1) if(F1.diff==1 & numClDy>1 & runSum==1)
		
	recode ongoing (1=0) if(numClDy>1 & runSum==1) // fix any of the ongoing crap.
	
	drop tempStDate tempEndDate


// deal with the 3-dyad cases (non-weird cases, the 2nd switch)
	// For the start date of dyad 3, needs to be equivalent to independence date
	gen tempStDate = indpDate1 if(numClDy==3 & (dispno2!=11 & dispno2!=12) & change2==1 & runSum==3 )
	replace tempStDate = indpDate2 if(numClDy==3 & (dispno2!=11 & dispno2!=12) & change2==2 & runSum==3 )
	format tempStDate %tm
	
	replace startDate = tempStDate if(numClDy==3 & (dispno2!=11 & dispno2!=12) & runSum==3 )

	
	// For end date of dyad 2, needs to be the month RIGHT BEFORE independence for 3
	sort dispno2 tempCounter
	
	gen tempEndDate = (t1 - 1) if(numClDy==3 & F1.change2==1 & (dispno2!=11 & dispno2!=12) & runSum==2)
	replace tempEndDate = (t2 - 1) if(numClDy==3 & F1.change2==2 & (dispno2!=11 & dispno2!=12) & runSum==2)
	format tempEndDate %tm	
	
	replace endDate = tempEndDate if(numClDy==3 & (dispno2!=11 & dispno2!=12) & runSum==2)
		// don't think I have to max this by claimDy, because of how the end obsvs fill in a little while.
	
	recode colonialEnd (0=1) if(F1.diff==1 & numClDy==3 & runSum==2)
		
	recode ongoing (1=0) if(numClDy==3 & runSum==2) // fix any of the ongoing crap.
	
	drop t1 t2 tempStDate tempEndDate
	
	
// Deal with the utterly bizarre, 3-dyad cases by hand.  (Actually contains three switches.)
* need a more accurate switch variable (and then need to make sure that other cases of this sort don't exist
gen switch = (claimDy!=L1.claimDy)
bysort dispno2 (datetm): egen double totalClDySw = total(switch)
bysort dispno2 (datetm): gen runSw = sum(switch)

sort dispno2 tempCounter 

* dispno2==11
	*** FIRST SWITCH ***
	// End date of first dyad is "death" of Ethiopia.
	replace endDate = tm(1936m5) if(dispno2==11 & runSw==1)
	recode colonialEnd (0=1) if(dispno2==11 & runSw==1 & F1.switch==1)
	recode ongoing (1=0) if(dispno2==11 & runSw==1 & F1.switch==1)
	
	// Start date of second dyad is the month following ETH's death
	replace startDate = tm(1936m6) if(dispno2==11 & runSw==2)
	
	
	*** SECOND SWITCH ***		{edited to comport with H&A's telling, which is ITA through 1943, then ETH in 1945 (put down as V-E Day)}
	// End date of second dyad is month before the "rebirth" of Ethiopia.
	replace endDate = tm(1943m12) if(dispno2==11 & runSw==2)
	recode colonialEnd (0=1) if(dispno2==11 & runSw==2 & F1.switch==1)
	recode ongoing (1=0) if(dispno2==11 & runSw==2 & F1.switch==1)
	
	// Start date of third dyad is "rebirth" of ETH
	replace startDate = tm(1945m5) if(dispno2==11 & runSw==3)
	
	
	*** THIRD SWITCH ***
	// End date of second dyad is month before the "birth" of Kenya.
	replace endDate = tm(1963m11) if(dispno2==11 & runSw==3)
	recode colonialEnd (0=1) if(dispno2==11 & runSw==3 & F1.switch==1)
	recode ongoing (1=0) if(dispno2==11 & runSw==3 & F1.switch==1)
	
	// Start date of third dyad is "birth" of Kenya
	replace startDate = tm(1963m12) if(dispno2==11 & runSw==4)
	
	
	

* dispno2==12	
	*** FIRST SWITCH ***
	// End date of first dyad is "death" of Ethiopia.
	replace endDate = tm(1936m5) if(dispno2==12 & runSw==1)
	recode colonialEnd (0=1) if(dispno2==12 & runSw==1 & F1.switch==1)
	recode ongoing (1=0) if(dispno2==12 & runSw==1 & F1.switch==1)
	
	// Start date of second dyad is the month following ETH's death
	replace startDate = tm(1936m6) if(dispno2==12 & runSw==2 )
	
	
	*** SECOND SWITCH ***  {edited to comport with H&A's telling, which is ITA through 1943, then ETH in 1945 (put down as V-E Day)}
	// End date of second dyad is month before the "rebirth" of Ethiopia.
	replace endDate = tm(1943m12) if(dispno2==12 & runSw==2 )
	recode colonialEnd (0=1) if(dispno2==12 & runSw==2 & F1.switch==1)
	recode ongoing (1=0) if(dispno2==12 & runSw==2 & F1.switch==1)
	
	// Start date of third dyad is "rebirth" of ETH
	replace startDate = tm(1945m5) if(dispno2==12 & runSw==3 )
	
	
	*** THIRD SWITCH ***
	// End date of second dyad is month before the "birth" of Sudan.
	replace endDate = tm(1955m12) if(dispno2==12 & runSw==3 )
	recode colonialEnd (0=1) if(dispno2==12 & runSw==3 & F1.switch==1)
	recode ongoing (1=0) if(dispno2==12 & runSw==3 & F1.switch==1)
	
	// Start date of third dyad is "birth" of Sudan
	replace startDate = tm(1956m1) if(dispno2==12 & runSw==4 )
	
	
// [13JUL14]  The handcodes, to get the right dates.
* dispno2==303	Not wrong, per se, but the H&A dates are different from EGY's indp. date in COW.  So, must handcode the transition.
	*** FIRST SWITCH ***
	// End date of first dyad is month before "birth" of Egypt (which H&A say is 1922)
	replace endDate = tm(1921m12) if(dispno2==303 & runSw==1 & F1.switch==1)
	recode colonialEnd (0=1) if(dispno2==303 & runSw==1 & F1.switch==1)
	recode ongoing (1=0) if(dispno2==303 & runSw==1 & F1.switch==1)
	
	// Start date of second dyad is the "birth" of Egypt, which H&A say is JAN1922
	replace startDate = tm(1922m1) if(dispno2==303 & runSw==2 & switch==1)
	
* dispno2==341.  Armenia didn't exist before 1991, hence the COW drama.  H&A have Armenia dying in last month of 1920--fine.
	*** FIRST SWITCH ***
	// End date of first dyad is month before birth of USSR, says H&A
	replace endDate = tm(1920m12) if(dispno2==341 & runSw==1 & F1.switch==1)
	recode colonialEnd (0=1) if(dispno2==341 & runSw==1 & F1.switch==1)
	recode ongoing (1=0) if(dispno2==341 & runSw==1 & F1.switch==1)
	
	// Start date of second dyad is the "birth" of USSR, say H&A
	replace startDate = tm(1921m1) if(dispno2==341 & runSw==2 & switch==1)
		
	
* dispno2==345.  Same general deal as 341.  COW says Georgia didn't exist before 1991; H&A disagree. 
	*** FIRST SWITCH ***
	// End date of first dyad is month before birth of USSR, says H&A
	replace endDate = tm(1920m12) if(dispno2==345 & runSw==1 & F1.switch==1)
	recode colonialEnd (0=1) if(dispno2==345 & runSw==1 & F1.switch==1)
	recode ongoing (1=0) if(dispno2==345 & runSw==1 & F1.switch==1)
	
	// Start date of second dyad is the "birth" of USSR, say H&A
	replace startDate = tm(1921m1) if(dispno2==345 & runSw==2 & switch==1)
	
	
**** FIX DISPNO2 11, 12, and 14 after the tsfill, full.  It's easier that way. ****	
	
// replace the length observations for the "fixed" guys
replace length = endDate - datetm if(switch==1 | F1.switch==1)	
	
} // end of colonial fix	
*	
	
	
// Appending the front observations [11JUL14]
id claimDy runSw, gen(claimDySwID)

xtset claimDySwID datetm
	
	// total N count
	count if(dispno2!=.)
	local max = `c(N)'

	
preserve
	tempfile mini starts
	
	* For the observations in which t0 = 0 AND the starting stage isn't challenge, append.
	bysort claimDySwID (datetm): gen panelTemp = _n
	save `mini', replace
		
	count if(dispno2!=.)
	local max = `c(N)'
	
	local counter = 0 //for `starts' save loop--need to go into the if when ==1, otherwise, the else
	di `max'
	qui{
		forvalues i=1/`max'{
			use `mini', clear
			tempfile cl`i'
			keep if(origCount==`i' & panelTemp==1 /*& stage!=0*/)	// added the stages condition, just to make sure I don't break something that doesn't need to be fixed
			
			// If there are observations left, then check the append conditions.
			count if(dispno2!=.)
	
			if(`r(N)'!=0){
				// Is the start date and datetm the same?
				if(datetm==startDate){
					// then do nothing.
				
				}
				
				else{
					local `counter++'

					expand 2, gen(appends)
					replace datetm = startDate if(appends==1)
					replace orig = 0 if(appends==1)
					
					
					drop if(orig==1)
					
					replace stage = 0	// for the observations at the start--should be challenges
					
					// reset all the other variables' values to missing
					foreach x of varlist dvsq1 length msafinal dupnegno dupmidno dvneg1 dvesc1 dvneg2 dvesc2 comopp allianceHA comadv2 comadv5- mixdyndm origCount{
						cap replace `x' = .
						if(_rc!=0){
							replace `x' = ""
						}
					}
					
					
					if(`counter'==1){
						save `starts', replace
					}
					else{
						save `cl`i'', replace
						use `starts', clear
						append using `cl`i''
						save `starts', replace
					}
				
				}
			}
		}
	}
	
restore
	append using `starts'
	recode orig (.=0)
	recode appends (.=0)
	order appends, after(orig)

	
sort claimDy datetm
	
	
	
// Appending the end observations.


// to deal with the obsvs that have missing endDates, and therefore, missing lengths
recode length (.=1) if(endDate==.)
replace endDate = datetm if(endDate==.)

preserve
	tempfile mini ends
	drop if(appends==1)	// get rid of the start additions, for now.
	drop appends
	save `mini', replace

	count if(dispno2!=.)
	local max = `c(N)'
	
	di `max'
	qui{
		forvalues i=1/`max'{
			use `mini', clear
			tempfile cl`i'
			keep if(origCount==`i')
			
			qui sum length
			
			if(`r(N)'!=0){
				local mx = `r(max)'
				local mn = `r(min)'
			}
			else{
				local mx = 0
				local mn = 0
			}
			if(`mx'==1){
				// do nothing.  there is nothing to append.
			}
			else if(`mn'<1){
				// also skip, because the value's negative
			}
			else{
				local max = `mx' - 1
				tsappend, add(`max')
				
				if(numClDy>1 & colonialEnd==1){	// to FORCE the multiple clDys to update with an end observation that will then be filled
									
									
					expand 2 if(orig==1 & datetm!=endDate), gen(appendE)
					order appendE, first
					
					replace datetm = endDate if(appendE==1)
					replace orig = 0 if(appendE==1)
					
					drop if(orig==1)
					
					replace stage = 0	// for the observations at the start--should be challenges
					
					
					// reset all the other variables' values to missing
					foreach x of varlist dvsq1 length msafinal dupnegno dupmidno dvneg1 dvesc1 dvneg2 dvesc2 comopp allianceHA comadv2 comadv5- mixdyndm origCount{
						cap replace `x' = .
						if(_rc!=0){
							replace `x' = ""
						}
					}

				}
				
			}
			
			egen double temp = max(dvsq1)
			replace stage = temp if(stage==.)
		
			drop if(orig==1)
			
			if(`i'==1){
				save `ends', replace
			}
			else{
				save `cl`i'', replace
				use `ends', clear
				append using `cl`i''
				save `ends', replace
			}
		}
	}
	use `ends'
	gen appends = 1
	cap drop appendE
	save `ends', replace
		
restore
	append using `ends'
	recode orig (.=0)
	order appends, after(orig)

sort claimDy datetm

replace stage = . if(appends==1)	// force the appended observations to missing, to be coded correctly by the other loops

// fill the monthly discrete + merge claim-dyad constant variables
duplicates tag claimDySwID datetm, gen(flag)
bysort claimDySwID datetm flag (orig): gen flagCount = _n
bysort claimDySwID datetm flag (orig): egen double flagCountMax = max(flagCount)

drop if(flag!=0 & flagCountMax!=flagCount)

// to fix the stupid 292 observation
replace datetm = endDate if(dispno2==292 & datetm==.)


tsfill


levelsof claimDySwID if(ongoing==1), local(cens)	// The more eloquent RC kludge (after everything's been appended in the initial tsfill)		** [11JUL14] BUT.  This will only be true for the last dispute-dyad in a panel.  NEEDS TO BE PART OF COLONY FIX.  !!!
foreach rc of local cens{
	tsappend, last(1995m12) tsfmt(tm) panel(`rc') 
}


gen fakePanel = sum(orig)
order fakePanel, first
	
recode orig (.=0)
recode appends (.=0)

bysort claimDySwID (datetm): egen double claimDyMax = max(claimDy)
replace claimDy = claimDyMax if(claimDy==.)
drop claimDyMax


bysort claimDySwID (datetm): egen double disp2Max = max(dispno2)
replace dispno2 = disp2Max if(dispno2==.)
drop disp2Max


// [13JUL14]  OK.  Just brute force fix.  Fill the ENTIRE series, for every claimDySwID, drop what's not necessary, and then fill the stages and stuff as needed
tsfill, full	
drop if(datetm<tm(1919m1))

recode orig (.=0)
recode appends (.=0)
	

bysort claimDySwID (datetm): egen double claimDyMax = max(claimDy)
replace claimDy = claimDyMax if(claimDy==.)
drop claimDyMax

bysort claimDySwID (datetm): egen double dispMax = max(dispno)
replace dispno = dispMax if(dispno==.)
drop dispMax	

bysort claimDySwID (datetm): egen double disp2Max = max(dispno2)
replace dispno2 = disp2Max if(dispno2==.)
drop disp2Max	
	
	
// The dispno2==11, 12, and 14 fix	(and any others)
	* basically, these disputes stop, then restart.  So, nuke the intervening observations.
		* dispno2==11.  Ends in 1943m12, starts up again in 1945m5 (assumed as VE Day)
		drop if(dispno2==11 & (datetm>tm(1943m12) & datetm<tm(1945m5)))
		recode switch (0=1) if(dispno2==11 & datetm==tm(1945m5))
		
		* dispno2==12.  Ends in 1943m12, starts up again in 1945m5 (assumed as VE Day)
		drop if(dispno2==12 & (datetm>tm(1943m12) & datetm<tm(1945m5)))
		recode switch (0=1) if(dispno2==12 & datetm==tm(1945m5))
		
		* dispno2==14.  Ends in 1936m12, starts up again in 1945m5 (assumed as VE Day)
		drop if(dispno2==14 & (datetm>tm(1936m12) & datetm<tm(1945m5)))
		recode switch (0=1) if(dispno2==14 & datetm==tm(1945m5))	
	
	* Any disps involving the Vietnams (dispno2==115, 127) The N. Vietnam dyad start date needs to be 1975m5, and end for S. Viet is 1975m4.
	// when challenger		127, 158
	replace startDate = tm(1975m5) if((dispno2==127 | dispno2==158) & chall==816)
	replace endDate = tm(1975m4) if((dispno2==127 | dispno2==158) & chall==817)
	
	// when target			114,
	replace startDate = tm(1975m5) if(dispno2==114 & target==816)
	replace endDate = tm(1975m4) if(dispno2==114 & target==817)
	
	
// trim the excess, at this point  (e.g., the obsvs for ETH-UKG after 1936m1)
* but, first.  deal with the odd dispno2==28 observation.  Because it's easier to kludge it, at this point, than try to find where it's getting odd.
replace endDate = . if(datetm!=tm(1960m8) & dispno2==28)
recode length (55=12) if(dispno2==28)

* now, trim.
bysort claimDySwID (datetm): egen double endMax = max(endDate)
bysort claimDySwID (datetm): egen double stMax = min(startDate)
format endMax stMax %tm


	*save "pre-fill and pre-trim.dta", replace
	
	
	drop if(datetm>endMax & orig!=1)			// [18JUL14]  might be able to get rid of orig==1.  Prelim suggests that it's causing some issues down the road (e.g., keeps ITA-UKG for 1936m1 for dispno2==11, when the dyad doesn't start until 1936m5)
	drop if(datetm<stMax & orig!=1)
			
		*save "pre-fill.dta", replace
		
		// Merge on the info-like variables, for the new obsvs
		sort claimDy datetm
		merge claimDy using `clDy', uniqusing sort nokeep update
		tab _m
		drop _m

		/* Handchecked all the cases that are orig==1, for the two criteria.  (32 in total).  
		   All are the remenants of the colonial correction, and should be dropped.  Some obsvs. have relevant info, though, which should be extracted.
		
				/* THE CHECK
				
					gen special = (datetm<stMax & orig==1)
					recode special (0=1) if((datetm>endMax & orig==1))
					bysort dispno2 (claimDySwID datetm): egen specMax = max(special)
					sort dispno2 datetm runSum
					order special, before(datetm)
					edit if specMax==1				*/
					
			** HOWEVER--shouldn't drop them until after the spell fills.  (so, after the huge loop next.)		*/
		// dispno2==36
		* the negot in 1960m8 is really between FRN and MOR, b/c MAA isn't indp. until 1960m11.  So, shift that info.
		local d = 36
		local chal = 600
		local tgt = 220
		
		replace stage = 1 if(datetm==tm(1960m8) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace length = 3 if(datetm==tm(1960m8) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace lengthBack = 4 if(datetm==tm(1960m8) & dispno2==`d' & challenger==`chal' & target==`tgt')

		// dispno2==44
		* the negot in 1963m8 is really between SOM and UKG, b/c KEN isn't indp. until 1963m12.  So, shift that info.
		local d = 44
		local chal = 520
		local tgt = 200
		
		replace stage = 1 if(datetm==tm(1963m8) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace length = 0 if(datetm==tm(1963m8) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace lengthBack = 1 if(datetm==tm(1963m8) & dispno2==`d' & challenger==`chal' & target==`tgt')

		// dispno2==72
		* the negot in 1981m3 is really between GUA and UKG, b/c BLZ isn't indp. until 1981m9.  So, shift that info.
		local d = 72
		local chal = 90
		local tgt = 200
		
		replace stage = 1 if(datetm==tm(1981m3) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace length = 1 if(datetm==tm(1981m3) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace lengthBack = 2 if(datetm==tm(1981m3) & dispno2==`d' & challenger==`chal' & target==`tgt')
		
		// dispno2==104
		* the negot in 1947m6 is really between FRN and UKG, b/c IND isn't indp. until 1947m8.  So, shift that info.
		local d = 104
		local chal = 200
		local tgt = 220
		
		replace stage = 1 if(datetm==tm(1947m6) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace length = 12 if(datetm==tm(1947m6) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace lengthBack = 13 if(datetm==tm(1947m6) & dispno2==`d' & challenger==`chal' & target==`tgt')
		
		// dispno2==272
		* the negot in 1961m1 is really between UKG and SAU, b/c KUW isn't indp. until 1961m6.  So, shift that info.
		local d = 272
		local chal = 200
		local tgt = 670
		
		replace stage = 1 if(datetm==tm(1961m1) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace length = 3 if(datetm==tm(1961m1) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace lengthBack = 4 if(datetm==tm(1961m1) & dispno2==`d' & challenger==`chal' & target==`tgt')
		
		* ((no corr required for second set of dyads))
		
		// dispno2==274
		* the negot in 1971m4 is really between UKG and SAU, b/c UAE isn't indp. until 1971m12.  So, shift that info.
		local d = 274
		local chal = 200
		local tgt = 670
		
		replace stage = 1 if(datetm==tm(1971m4) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace length = 8 if(datetm==tm(1971m4) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace lengthBack = 9 if(datetm==tm(1971m4) & dispno2==`d' & challenger==`chal' & target==`tgt')
		
		// dispno2==292
		* the negot in 1932m4 is really between UKG and IRN, b/c IRQ isn't indp. until 1932m10.  So, shift that info.
		local d = 292
		local chal = 630
		local tgt = 200
		
		replace stage = 1 if(datetm==tm(1932m4) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace length = 1 if(datetm==tm(1932m4) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace lengthBack = 2 if(datetm==tm(1932m4) & dispno2==`d' & challenger==`chal' & target==`tgt')
		
		// dispno2==324
		* the negot in 1961m1 is really between UKG and SAU, b/c KUW isn't indp. until 1961m6.  So, shift that info.
		local d = 324
		local chal = 670
		local tgt = 200
		
		replace stage = 1 if(datetm==tm(1961m1) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace length = 3 if(datetm==tm(1961m1) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace lengthBack = 4 if(datetm==tm(1961m1) & dispno2==`d' & challenger==`chal' & target==`tgt')
			
		// dispno2==327
		* the negot in 1971m4 is really between UKG and SAU, b/c UAE isn't indp. until 1971m12.  So, shift that info.
		local d = 327
		local chal = 670
		local tgt = 200
		
		replace stage = 1 if(datetm==tm(1971m4) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace length = 8 if(datetm==tm(1971m4) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace lengthBack = 9 if(datetm==tm(1971m4) & dispno2==`d' & challenger==`chal' & target==`tgt')
			
		// dispno2==328
		* the negot in 1971m4 is really between UKG and SAU, b/c OMA isn't indp. until 1971m10.  So, shift that info.
		local d = 328
		local chal = 670
		local tgt = 200
		
		replace stage = 1 if(datetm==tm(1971m4) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace length = 8 if(datetm==tm(1971m4) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace lengthBack = 9 if(datetm==tm(1971m4) & dispno2==`d' & challenger==`chal' & target==`tgt')
		
		// dispno2==337
		* the negot in 1990m11 is really between YEM and OMA, b/c YPR becomes YEM in 1990m5.
		local d = 337
		local chal = 679
		local tgt = 698
		
		replace stage = 1 if(datetm==tm(1990m11) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace length = -7 if(datetm==tm(1990m11) & dispno2==`d' & challenger==`chal' & target==`tgt')
		replace lengthBack = 2 if(datetm==tm(1990m11) & dispno2==`d' & challenger==`chal' & target==`tgt')
		
		
// Code the stage for the added obsvs (for computing stageDuration)
qui sum lengthBack if(stage!=0 & stage!=.)
sort claimDySwID datetm

forvalues top=2/`r(max)'{
	local current = `top' - 1
		forvalues code = 1/`current'{
			qui replace stage = L`code'.stage if(L`code'.lengthBack==`top' & orig!=1 & L`code'.orig==1)
		}
		
}


	*save "post-fill.dta", replace

	
// orig drops here
	drop if(datetm>endMax & orig==1)
	drop if(datetm<stMax & orig==1)
	

recode stage (.=0)	// all the recodes appear to be right--i.e., they should be 0s

// Merge on the info-like variables, for the new obsvs
sort claimDy datetm
merge claimDy using `clDy', uniqusing sort nokeep update
tab _m
drop _m

	
		
		


// create stage variable	((are multiple stages possible at once? - e.g., negotiation and military conflict))	** 2c **
	* 0 = do nothing
	* 1 = negotiations
	* 2 = military action
	* 3 = resolved		(28MAY14 - added) => see the continuous do-file
	
// fix the ninja Grover
replace runSum = 2 if(dispno2==14 & datetm>=tm(1945m1))
replace claimDySwID = 145302002 if(dispno2==14 & datetm>=tm(1945m1))

	 
bysort claimDySwID (datetm): egen double maxLength = max(length)


// to deal with the observations at the very end of a claim-dyad panel (e.g., 1211235 in 1935m3)
sort claimDySwID datetm
genD transition = 1 if(stage!=L1.stage), dummy
	

order transition, after(stage)
bysort claimDySwID (datetm): gen fakePanel2 = sum(transition)
order fakePanel2, after(fakePanel)

	
order colonialEnd, first


//create new duration variable (length of time in stage)
drop origCount tempCounter panelTemp temp flag flagCount flagCountMax
gen temp = 1


bysort claimDySwID fakePanel2 (datetm): egenD stageDuration = total(temp), label(Time in stage, in months)

order stageDuration, after(transition)



// Right censored: anything ongoing at end of 1995 for sure (FIXED ELSEWHERE.)
order ongoing, after(stageDuration)	


// Merge in the state names, again, because H&A have "NA" for certain ccodes that aren't NA
merge challenger using `states', uniqusing sort nokeep keep(name)
tab _merge
rename name chalN
drop _merge

merge target using `states', uniqusing sort nokeep keep(name)
tab _merge
rename name tgtN
drop _merge

// replace the stupid NAs, if they exist, and then drop the new variable
gen chalName = chgname if(chgname!="NA")
label variable chalName `"Challenger state name (with COW remerge for missings)"'
	replace chalName = chalN if(chalName=="")
gen tgtName = tgtname if(tgtname!="NA") 
label variable tgtName `"Target state name (with COW remerge for missings)"'
	replace tgtName = tgtN if(tgtName=="")	
	
order chalName tgtName, after(tgtname)

drop chalN tgtN


label variable dispno `"H&A: Disp. ID, by region"'
label variable dispno2 `"H&A: Disp. ID, overall"'



// ---  Save the discrete time version ---
cd ..

sort dispno2 datetm claimDy

compress
saveold "1 - h&a - discrete.dta", replace

// DONE.  Switch
