*****************************************************************************************
// Start bashing it into continuous mstate format
*****************************************************

use "4 - huth_allee_statusquodata, v0 (orig).dta" , clear
tempfile mMonth mYear mPrvYr mPrvYr2 mNxtYr

// DUAL CODING FIX (27OCT14)
foreach v of numlist 95 214 215 223 251{
	recode dual (0=1) if(dispno2==`v')
}

id dispno2 chall targ datetm, gen(claimDyMonth)
format claimDyMonth %tm

// month
preserve
	duplicates drop claimDyMonth, force
	clonevar tmT = datetm
	replace tmT = tm(1919m1) if(dispno2==75 & datetm==tm(1935m10))
	id dispno2 chall targ tmT, gen(special)
	save `mMonth', replace
	
	qui count if(dvsq1!=0)
	local origs = `r(N)'
restore

// year
preserve
	gen year = year(dofm(datetm))
	id dispno2 chall targ year, gen(claimDyYr)

	bysort dispno2 chall targ year (datetm): gen count = _n
	keep if(count==1)		// keep the first observation in a particular year for the claimDy
		
	save `mYear', replace
	
restore


// last month in previous year
preserve
	gen year = year(dofm(datetm))
	id dispno2 chall targ year, gen(claimDyPrYr)

	bysort dispno2 chall targ year (datetm): gen count = _n
	bysort dispno2 chall targ year (datetm): egen maxCount = max(count)
	keep if(count==maxCount)		// keep the first observation in a particular year for the claimDy
		
	save `mPrvYr', replace

restore

// last month in year before last year
preserve
	gen year = year(dofm(datetm)) 
	id dispno2 chall targ year, gen(claimDyPrYr2)

	bysort dispno2 chall targ year (datetm): gen count = _n
	bysort dispno2 chall targ year (datetm): egen maxCount = max(count)
	keep if(count==maxCount)		// keep the first observation in a particular year for the claimDy
		
	save `mPrvYr2', replace
restore


// first month in next year
preserve
	gen year = year(dofm(datetm)) 
	id dispno2 chall targ year, gen(claimDyNxtYr)

	bysort dispno2 chall targ year (datetm): gen count = _n
	bysort dispno2 chall targ year (datetm): egen maxCount = max(count)
	keep if(count==maxCount)		// keep the first observation in a particular year for the claimDy
		
	save `mNxtYr', replace
restore
**************************************
cd "$dir"
cd ..

use "1 - h&a - discrete.dta", replace
drop endDate

// DUAL CODING FIX (27OCT14)
foreach v of numlist 95 214 215 223 251{
	recode dual (0=1) if(dispno2==`v')
}


// keep first observation in spell only
bysort claimDySwID fakePanel2 (datetm): gen fP2Count = sum(temp)	// inner fakePanel2 counter
order fP2Count, first

keep if(fP2Count==1)

		
// transitions to which stage next
xtset claimDySwID fakePanel2
genD nextStage = F1.stage, label(Next possible stage)
genD prevStage = L1.stage, label(Previous occupied stage)				// In order to gen dummies for previous stage [09JUL14]
	qui tab prevStage, gen(prvStg)	//the actual dummies for previous stage [09JUL14]
order nextStage, after(stage)
order prevStage prvStg1 prvStg2 prvStg3, after(ongoing)
	// Set up the transition to resolved
	recode nextStage (.=3)

	// For the dummies for previous stage, code the first observation (initial challenge) to zero [09JUL14]
	recode prevStage prvStg* (.=0)
	label variable prvStg1 `"Previous stage = challenge"'
	label variable prvStg2 `"Previous stage = negotiations"'
	label variable prvStg3 `"Previous stage = military"'

	
rename transition status
label variable stage `"Current stage"'
label variable status `"1 if this transition observed, 0 if not"'
label variable stageDuration `"Time in stage, in months"'
		// Need variable for right censored vs. concluded, for final stages.
		* 14MAY14, 1729 EDT: DONE.  Simply need to verify whether the coding is correct, or whether
		* a more precise variable exists other than "hey, observation in DEC95--RC'd!"

// Fixing the stupid RC stuff.  Should never transition to resolved, if dispute is still ongoing.  [09JUL14]
recode status (1=0) if(nextStage==3 & ongoing==1)

	
// Generate the running counter for transitions within a dispute-dyad [09JUL14]
bysort claimDySwID (datetm): genD numTransitions = sum(status), label(Running number of disp-dy-sw transitions (e.g., 1 = on 1st transition))
genD numTransitionsEx = numTransitions - 1, label(Exclusive count for numTransitions (e.g., 0 = about to experience 1st transition, 1 = 2nd, etc.))
	recode numTransitionsEx (-99/-1=0)
bysort claimDySwID (datetm): egenD numTranMax = max(numTransitions), label(Dispute-dyad-sw's total number of observed transitions [adj. for RC])
	/*replace numTranMax = numTranMax - 1 if(ongoing==1 & // adjusted for right censoring--take away one transition */

order numTrans* numTranM, after(stageDuration)


// Generate the running count for each stage (0 = never here before, 1 = here once before...)	[09JUL14]
// run an inclusive count, too, to resolve headaches [22JUL14]
gen status_chal = status if(stage==0)
gen status_neg = status if(stage==1)
gen status_mil = status if(stage==2)

foreach x in chal neg mil{
	bysort claimDySwID (stage datetm): genD stageCnt_`x'Ex = (sum(status_`x') - 1), label(Stage counter for `x', exclusive (0 = never in stage before, 1 = here once...))
	recode stageCnt_`x'Ex (-99/-1=0)
	
	bysort claimDySwID (datetm): genD stageCnt_`x' = (sum(status_`x')), label(Stage counter for `x', inclusive)
	recode stageCnt_`x' (-99/-1=0)
}


	
* THEN, do the max for every dispute-dyad, for future sum stats--exclusive
foreach x of varlist stageCnt_chalEx stageCnt_negEx stageCnt_milEx{
	bysort claimDySwID (datetm): egenD `x'Max = max(`x'), label(By dispute-dyad-sw [exclusive], # of times in stage for `x')
}


	
* THEN, do the max for every dispute-dyad, for future sum stats--inclusive
foreach x of varlist stageCnt_chal stageCnt_neg stageCnt_mil{
	bysort claimDySwID (datetm): egenD `x'Max = max(`x'), label(By dispute-dyad-sw [inclusive], # of times in stage for `x')
}
	
order stageCnt* stageCnt_chal* stageCnt_neg* stageCnt_mil*, after(stageDuration)
recode stageCnt* (.=0)

drop status_*

		
// Gen the t0 and t variables
genD t0 = 0, label(t0: Starting clock time for duration)
order t0, before(stage)
sort claimDySwID fakePanel2
replace t0 = L.stageDuration   if(fakePanel2==2)		// No +1, because we're starting the count from zero.
replace t0 = L.stageDuration + L.t0 if(fakePanel2>2)
	
gen t = (t0 + stageDuration) 					// -1, because we're starting the count from zero.
order t, after(t0)

xtset claimDySwID datetm


pause off
pause

// control fills.  merge in, as needed, from the original dataset--try it by datetm first, and if that doesn't work, update based on FIRST month in the year (closest is too much of a pain to code, at the moment)
id dispno2 chall targ datetm, gen(claimDyMonth)
clonevar special = claimDyMonth

gen year = year(dofm(datetm))
id dispno2 chall targ year, gen(claimDyYr)

gen prYear = year(dofm(datetm)) - 1
id dispno2 chall targ prYear, gen(claimDyPrYr)

gen prYear2 = year(dofm(datetm)) - 2
id dispno2 chall targ prYear2, gen(claimDyPrYr2)	

gen nxtYr = year(dofm(datetm)) + 1 
id dispno2 chall targ nxtYr, gen(claimDyNxtYr)

merge claimDyMonth using `mMonth', uniqusing sort nokeep keep(milratio strvalue alliance tgtodi chgodi netdemoc onetdem) update 
tab _m
drop _m

pause

merge claimDyYr using `mYear', uniqusing sort nokeep keep(milratio strvalue alliance tgtodi chgodi netdemoc onetdem) update 
tab _m
drop _m

pause

merge claimDyPrYr using `mPrvYr', uniqusing sort nokeep keep(milratio strvalue alliance tgtodi chgodi netdemoc onetdem) update 
tab _m
drop _m

pause

merge claimDyPrYr2 using `mPrvYr2', uniqusing sort nokeep keep(milratio strvalue alliance tgtodi chgodi netdemoc onetdem) update 
tab _m
drop _m

pause

merge claimDyNxtYr using `mNxtYr', uniqusing sort nokeep keep(milratio strvalue alliance tgtodi chgodi netdemoc onetdem) update 
tab _m
drop _m

pause

merge special using `mMonth', uniqusing sort nokeep keep(milratio strvalue alliance tgtodi chgodi netdemoc onetdem) update // for the lone cheese
tab _m
drop _m



// THE CHECKS - check orig counts (# of 1s should match/be pretty close for non-challenge); compare length for non-challenge spells (should be pretty much identical, aside from the colonial legacy stupidness)
tab orig if(status==1 & stage!=0)
di "`origs'"
	// checked a few of the discrepant cases--they're all instances in which there's a back-to-back MID, negotiation, etc., which means we have one fewer obsv. than H&A.  Score.

merge claimDyMonth using `mMonth', uniqusing sort keep(length dvsq1)
tab _m

sum length stageDuration if(stage!=0 & status==1 & numClDy==1)	// not bad at all.  Looks like things are either off by 1 (makes sense, since H&A count different than us), or they're off larger amounts only because H&A seem to code some things by 12-month brackets (e.g., dispno2==21, in 1928m1 and 1929m1 => back-to-back negotiations)
sum length stageDuration if(stage!=0 & status==1 & numClDy>1)	// this one's more terrifying.  But, eyeballing it, all of the differnces have to do with the adjustments, it seems.  So, win?

drop if(_m==2)
drop _m

pause off
pause



// Duplicate 3 times, gen a flag for it	 => need four possibilities (for the transitions into resolved) - 28MAY14, 1034 EDT
expand 5, gen(exp)	
	recode status (1=0) if(exp==1) 	//resetting status to 0
	recode orig (1=0) if(exp==1) 	//resetting orig to 0
order exp, first
sort claimDy datetm exp	

pause

// gen all poss combos for nextStage
bysort claimDySwID datetm exp: gen tempStg = (_n-1)
order tempStg, after(nextStage)
replace nextStage = tempStg if(exp==1)		
drop tempStg		

		
// drop the impossibles
drop if(stage==nextStage & exp==1)	// e.g.) 0 -> 0 (imposs)

duplicates tag claimDy datetm nextStage, gen(tFlag)
order tFlag, after(status)
drop if(tFlag==1 & exp==1)			// the duplicate for the actual transition obsv		
drop tFlag

bysort claimDySwID (t0): egen ongoingMax = max(ongoing)
replace ongoing = ongoingMax if(ongoing==.)

// Gen the transID variable
gen transID = ""
replace transID = "A" if(stage==0 & nextStage==1)
replace transID = "B" if(stage==0 & nextStage==2)
	replace transID = "G" if(stage==0 & nextStage==3)
replace transID = "C" if(stage==1 & nextStage==0)
replace transID = "D" if(stage==1 & nextStage==2)
	replace transID = "H" if(stage==1 & nextStage==3)
replace transID = "E" if(stage==2 & nextStage==0)
replace transID = "F" if(stage==2 & nextStage==1)
	replace transID = "I" if(stage==2 & nextStage==3)


// gen number version of transID
egenD transIDn = group(transID), label(Numerical ID for transitions)
order transIDn, after(transID)

	* gen version of trans that R will like [08JUL14]
	genD trans = ., label(R-friendly version of transIDn)
	order trans, after(transIDn)
	
	recode trans (.=1) if(transID=="A")
	recode trans (.=2) if(transID=="B")
	recode trans (.=3) if(transID=="G")
	recode trans (.=4) if(transID=="C")
	recode trans (.=5) if(transID=="D")
	recode trans (.=6) if(transID=="H")
	recode trans (.=7) if(transID=="E")
	recode trans (.=8) if(transID=="F")
	recode trans (.=9) if(transID=="I")
	

// Figure out which variables need to stay, and duplicate them
bysort claimDySwID t0 (stage nextStage): gen cntTemp = _n
gen doubleTemp = numTranM + 1
genD sampleFlag = (status==1 | (ongoing==1 & fakePanel2==doubleTemp & cntTemp==1)), label(=1 for descriptive stats observations)

genD rcSpell = (ongoing==1 & fakePanel2==doubleTemp), label(1 if *spell* is RC'd.)
order rcSpell, after(ongoing)

drop doubleTemp cntTemp


// Add variable with # of dyads in entire dispute
drop diff numClDy
bysort dispno2 (claimDy datetm): gen diff = (claimDy[_n] !=claimDy[_n-1])
bysort dispno2 (claimDy datetm): egenD numClDy = total(diff), label(Total number of dyads in dispute)

order numClDy, first

keep length claimDyMonth claimDySwID sampleFlag numClDy rcSpell exp orig claimDy dispno dispno2 region challenger- status stageDuration ///
	 numTran* prevSt* prv* stageCnt* trans transID ongoing chalName tgtName dual dupnegno dupmidno milratio strvalue alliance tgtodi chgodi netdemoc onetdem /*msafinal*/
drop startDate
	 
// Getting the control variables set



* loop once complete	 
foreach x of varlist milratio strvalue alliance tgtodi chgodi netdemoc onetdem{
	foreach let in A B C D E F G H I {
		clonevar `x'`let'=`x'
		replace `x'`let' = 0 if(transID!="`let'")
		label variable `x'`let' `"Value of `x' for transid==`let'"'
	}
}



drop length claimDyMonth

// Merge in the ICOW stuff, to help adjudicate between which duals to drop (28OCT14)

preserve
	tempfile duals
	import excel "assembly files/dual dispno2 codes.xlsx", sheet("Sheet1") firstrow clear
	destring icowClaim-icowTgt2, replace
	egen icowKeep_all = rowmax(icowKeep icowKeep2)
	id dispno2 chal tgt, gen(claimDy)
	save `duals', replace
restore

merge claimDy using `duals', uniqusing sort nokeep keep(icowKeep_all)
drop _merge
clonevar icowFlag = icowKeep_all
recode icowFlag (.=1)

label variable icowKeep_all `"=1 if dual & in ICOW as chal-tgt pair, =0 if dual & not chal-tgt pair"'
label variable icowFlag `"FLAG: =1 for all non-duals, ICOW-resolved duals, and duals not in ICOW at all"'

// Housekeep		
notes: Last modified: TS
notes: Modified by: `c(username)' 

order exp orig, last
compress

cd "$dir"
cd ..

sort dispno2 datetm nextStage

saveold "2 - h&a - continuous, no TVC.dta", replace
label data `"Last modified: `c(filedate)'; Modified by: `c(username)'"'
saveold "2 - h&a - continuous, no TVC.dta", replace


*******************************************************************************
// Create the disaggregated stage dataset (5 stages) [24JAN15]	

// recode all the stages to the "simple" Excel spreadsheet numbers
recode stage nextStage (0=1) (1=2) (2=3) (3=5)


// recodes for disagg
* inactivity
recode stage (1=4) if( (stageCnt_chal>1 & stageCnt_chal < .) | (stageCnt_chalEx==0 & numTransitionsEx>=1) )
recode nextStage (1=4) if(numTransitionsEx>0 | t0==0)


* 27JUL14: put in a JIC clean-up statement for the cases that don't start in Challenge.  We know if anyone's in 2 or 3, then they're possibly transitioning to 5 next (not 1)
recode nextStage (1=4) if(stage==2 | stage==3)



* recode the transition variables
drop trans
	genD trans = ., label(R-friendly version, transit #s)
	order trans, before(sampleFlag)
	
	recode trans (.=1) if(stage==1 & nextStage==2)
	recode trans (.=2) if(stage==1 & nextStage==3)
	recode trans (.=3) if(stage==1 & nextStage==5)
	
	recode trans (.=4) if(stage==2 & nextStage==3)
	recode trans (.=5) if(stage==2 & nextStage==4)
	recode trans (.=6) if(stage==2 & nextStage==5)
	
	recode trans (.=7) if(stage==3 & nextStage==2)
	recode trans (.=8) if(stage==3 & nextStage==4)
	recode trans (.=9) if(stage==3 & nextStage==5)
	
	recode trans (.=10) if(stage==4 & nextStage==2)
	recode trans (.=11) if(stage==4 & nextStage==3)
	recode trans (.=12) if(stage==4 & nextStage==5)


* gen all the controls again
foreach x of varlist milratio strvalue allianceHA tgtodi chgodi netdemoc onetdem{
	drop `x'?
	
	forvalues v =1/12 {
		clonevar `x'`v'=`x'
		replace `x'`v' = 0 if(trans!=`v')
		label variable `x'`v' `"Value of `x' for transid==`v'"'
	}
}


* save.
sort dispno2 datetm nextStage
compress

cd "$dir"
cd ..

saveold "4 - h&a - continuous, disagg stages (5 stgs)", replace
label data `"Last modified: `c(filedate)'; Modified by: `c(username)'"'
saveold "4 - h&a - continuous, disagg stages (5 stgs)", replace
	
